// cc2serDlg.cpp : implementation file
//

#include "stdafx.h"
#include "cc2ser.h"
#include "cc2serDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


#define WriteBufferSize 1024

extern "C" {
void crc_init(unsigned char *crclow, unsigned char *crchigh);
void crc_calc(unsigned char *crclow, unsigned char *crchigh, unsigned char x);
}
BOOL ReadRegString(HKEY hKey, LPTSTR name, BYTE *buffer, DWORD buffersize);
BOOL ReadRegDWORD(HKEY hKey, LPTSTR name, LPDWORD data);

static OPENFILENAME ofn;						/* Structure used by the "Open File" dialogbox */
static TCHAR szInputFileName[MAX_PATH];			/* Space for the filename */


extern CCC2serDlg *theDlg;

UINT SerialDownloadThread(LPVOID pParam)
{
	serStats *pStats = (serStats *)pParam;
	unsigned char *pWrite;
	DWORD nWriteLength,nLengthWritten,nMask;
	BOOL bErrors = FALSE;

	pWrite = pStats->pBuffer;
	do
	{
		nWriteLength = (pStats->dwFilesize >= WriteBufferSize ? WriteBufferSize : pStats->dwFilesize);
		if(!WriteFile(theDlg->m_hComPort, pWrite, nWriteLength, &nLengthWritten, NULL))
		{
			AfxMessageBox("Error writing to COM port!");
			bErrors = TRUE;
		}
		if(nLengthWritten != nWriteLength)
		{
			AfxMessageBox("Error writing to COM port!");
			bErrors = TRUE;
		}

		WaitCommEvent(theDlg->m_hComPort, &nMask, NULL);

		if(nMask & EV_ERR || nMask & EV_BREAK)
		{
			AfxMessageBox("Error writing to COM port!");
			bErrors = TRUE;
		}

		pWrite += nWriteLength;
		pStats->dwFilesize -= nWriteLength;
		theDlg->m_cDLProgress.StepIt();
	}while(pStats->dwFilesize > 0 && !bErrors && !theDlg->m_bStopSending);

	if(!theDlg->m_bStopSending)
	{
		if(!FlushFileBuffers(theDlg->m_hComPort))
		{
			AfxMessageBox("Unable to flush COM port transmit buffers!");
			bErrors = TRUE;
		}
	}

	delete pStats->pBuffer;
	delete pStats;
	theDlg->CloseComPort();

	theDlg->m_cDLProgress.ShowWindow(SW_HIDE);
	theDlg->m_cSend.SetWindowText("Send");
	theDlg->m_bSending = FALSE;
	return(0);
}
/////////////////////////////////////////////////////////////////////////////
// CCC2serDlg dialog


CCC2serDlg::CCC2serDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CCC2serDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CCC2serDlg)
	m_sPort = _T("");
	m_sBankswitch = _T("");
	m_sStartup = _T("");
	m_sBinfile = _T("");
	m_sBaudrate = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(CCICON);
}

void CCC2serDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CCC2serDlg)
	DDX_Control(pDX, IDC_SEND, m_cSend);
	DDX_Control(pDX, IDC_PROGRESS_DL, m_cDLProgress);
	DDX_Control(pDX, IDC_RADIO_MANUAL, m_cRadioManual);
	DDX_Control(pDX, IDC_RADIO_AUTO, m_cRadioAuto);
	DDX_Control(pDX, IDC_BAUDRATE, m_cBaudrate);
	DDX_Control(pDX, IDC_STARTUP, m_cStartup);
	DDX_Control(pDX, IDC_BANKSWITCH, m_cBankswitch);
	DDX_Control(pDX, IDC_PORT, m_cPort);
	DDX_CBString(pDX, IDC_PORT, m_sPort);
	DDX_CBString(pDX, IDC_BANKSWITCH, m_sBankswitch);
	DDX_CBString(pDX, IDC_STARTUP, m_sStartup);
	DDX_Text(pDX, IDC_BINFILE, m_sBinfile);
	DDX_CBString(pDX, IDC_BAUDRATE, m_sBaudrate);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CCC2serDlg, CDialog)
	//{{AFX_MSG_MAP(CCC2serDlg)
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_SEND, OnSend)
	ON_BN_CLICKED(IDC_BROWSE, OnBrowse)
	ON_BN_CLICKED(IDC_RADIO_AUTO, OnRadioAuto)
	ON_BN_CLICKED(IDC_RADIO_MANUAL, OnRadioManual)
	ON_WM_CLOSE()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CCC2serDlg message handlers

BOOL CCC2serDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here

	m_cBankswitch.LimitText(8);
	m_cBankswitch.AddString("2K");
	m_cBankswitch.AddString("4K");
	m_cBankswitch.AddString("3F");
	m_cBankswitch.AddString("7800_4K");
	m_cBankswitch.AddString("7800_8K");
	m_cBankswitch.AddString("7800_16K");
	m_cBankswitch.AddString("7800_32K");
	m_cBankswitch.AddString("7800_48K");
	m_cBankswitch.AddString("78POKEY");
	m_cBankswitch.AddString("78SC_BIG");
	m_cBankswitch.AddString("78SC_LOW");
	m_cBankswitch.AddString("78SC_POK");
	m_cBankswitch.AddString("78SC_R16");
	m_cBankswitch.AddString("78SC_R8K");
	m_cBankswitch.AddString("78SC_SM");
	m_cBankswitch.AddString("78SCR8SM");
	m_cBankswitch.AddString("ABS78");
	m_cBankswitch.AddString("ACT78");
	m_cBankswitch.AddString("CV");
	m_cBankswitch.AddString("E0");
	m_cBankswitch.AddString("E7");
	m_cBankswitch.AddString("F4");
	m_cBankswitch.AddString("F4SC");
	m_cBankswitch.AddString("F6");
	m_cBankswitch.AddString("F6SC");
	m_cBankswitch.AddString("F8");
	m_cBankswitch.AddString("F8R");
	m_cBankswitch.AddString("F8SC");
	m_cBankswitch.AddString("FA");
	m_cBankswitch.AddString("FANR");
	m_cBankswitch.AddString("FE");
	m_cBankswitch.AddString("HSC_16K");
	m_cBankswitch.AddString("HSC_32K");
	m_cBankswitch.AddString("HSC_48K");
	m_cBankswitch.AddString("MEGABOY");
	m_cBankswitch.AddString("SC");
	m_cBankswitch.AddString("UA");


	m_cStartup.LimitText(8);
	m_cStartup.AddString("78BIOS");
	m_cStartup.AddString("HSC");
	m_cStartup.AddString("SC");
	m_cStartup.AddString("26QUICK");
	m_cStartup.AddString("78QUICK");
	m_cStartup.AddString("HSCQUICK");
	m_cStartup.AddString("F6BANK0");
	m_cStartup.AddString("F8BANK1");



	char Portnum;
	char Portname[] = "COM1";
	CFile fTest;

	for(Portnum = '1'; Portnum <= '9'; Portnum++)
	{
		Portname[3] = Portnum;
		if(fTest.Open(Portname, CFile::modeCreate | CFile::modeWrite | CFile::shareExclusive))
		{
			fTest.Close();
			m_cPort.AddString(Portname);
		}
	}
	m_bComPortOpen = FALSE;
	m_bSending = FALSE;

	/* Filter for File dialogbox */
	static TCHAR szFilter[] = TEXT("BIN Files (*.BIN)\0*.bin\0")  \
								TEXT("All Files (*.*)\0*.*\0\0");	

	/* Fill File Open dialogbox structure */
	ofn.lStructSize       = sizeof(OPENFILENAME);	/* Struct size */
	ofn.hwndOwner         = this->m_hWnd;			/* Owner window */
	ofn.hInstance         = NULL;
	ofn.lpstrFilter       = szFilter;				/* Filter */
	ofn.lpstrCustomFilter = NULL;
	ofn.nMaxCustFilter    = 0;
	ofn.nFilterIndex      = 0;						/* Selected filter index */
	ofn.nMaxFile          = MAX_PATH;				/* Max. characters for filename */
	ofn.nMaxFileTitle     = MAX_PATH;
	ofn.lpstrInitialDir   = NULL;					/* Initial directory */
	ofn.lpstrTitle        = NULL;					/* Title of dialogbox */
	ofn.nFileOffset       = 0;
	ofn.nFileExtension    = 0;
	ofn.lpstrDefExt       = TEXT("BIN");			/* Default extension */
	ofn.lCustData         = 0L;
	ofn.lpfnHook		= NULL;
	ofn.lpTemplateName	= NULL;
	ofn.lpstrFile		= szInputFileName;			/* Filename buffer */
	ofn.lpstrFileTitle	= NULL;
	ofn.Flags			= 0 ;


	LoadSettings();
	return TRUE;  // return TRUE  unless you set the focus to a control
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CCC2serDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, (WPARAM) dc.GetSafeHdc(), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CCC2serDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

void CCC2serDlg::OnBrowse() 
{
	// TODO: Add your control notification handler code here
	if (GetOpenFileName(&ofn)) SetDlgItemText(IDC_BINFILE, szInputFileName);	
}

void CCC2serDlg::OnSend() 
{
	UpdateData();
	if(m_bSending)
	{
		m_bStopSending = TRUE;
		return;
	}
	if(m_sBinfile.IsEmpty())
		return;
	if(m_cRadioAuto.GetCheck())
	{
		if(m_sBankswitch.IsEmpty())
		{
			AfxMessageBox("Must specify a bankswitch file.");
			return;
		}
		if(m_sStartup.IsEmpty())
		{
			AfxMessageBox("Must specify a startup file.");
			return;
		}
	}
			
	if(!m_bComPortOpen)
	{
		if(!OpenComPort())
		{
			AfxMessageBox("Cannot open COM Port!");
			return;
		}
	}

	unsigned char *pBuffer = NULL;
	TRY
	{
		pBuffer = new unsigned char[514*1024];
	}
	CATCH(CMemoryException, e)
	{
		e->Delete();
		AfxMessageBox("Error allocating memory for ROM!");
		return;
	}
	END_CATCH;

	DWORD dwFilesize, dwBytesRead;
	unsigned char *pWrite;

	HANDLE hFile;

	/* Open file */
	if((hFile=CreateFile(m_sBinfile, GENERIC_READ, FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL))==INVALID_HANDLE_VALUE)
	{
		AfxMessageBox("Unable to open selected file.");
		return;
	}

	dwFilesize = GetFileSize(hFile,NULL);
	if(dwFilesize > 512*1024)
	{
		AfxMessageBox("Selected file is too large.");
		CloseHandle(hFile);
		return;
	}

	if((dwFilesize % 1024) != 0)
	{
		AfxMessageBox("Filesize must be a multiple of 1K.");
		CloseHandle(hFile);
		return;
	}
	
	pWrite = pBuffer;
	if(m_cRadioAuto.GetCheck())
	{
		m_sBankswitch.MakeUpper();
		m_sStartup.MakeUpper();
		unsigned int j;
		int i;
		unsigned char crclow,crchigh;
		crc_init(&crclow,&crchigh);
		*((unsigned short *)pWrite) = (unsigned short)(dwFilesize/1024);
		crc_calc(&crclow,&crchigh,*(pWrite++));
		crc_calc(&crclow,&crchigh,*(pWrite++));
		for(i = 0; i < m_sBankswitch.GetLength(); i++)
		{
			*(pWrite) = (unsigned char)m_sBankswitch.GetAt(i);
			crc_calc(&crclow,&crchigh,*(pWrite++));
		}
		for(i = m_sBankswitch.GetLength(); i < 8; i++)
		{
			*(pWrite) = ' ';
			crc_calc(&crclow,&crchigh,*(pWrite++));
		}
		for(i = 0; i < m_sStartup.GetLength(); i++)
		{
			*(pWrite) = (unsigned char)m_sStartup.GetAt(i);
			crc_calc(&crclow,&crchigh,*(pWrite++));
		}
		for(i = m_sStartup.GetLength(); i < 8; i++)
		{
			*(pWrite) = ' ';
			crc_calc(&crclow,&crchigh,*(pWrite++));
		}
		*(pWrite++) = crchigh;
		*(pWrite++) = crclow;

		for(j = 0; j < dwFilesize/1024; j++)
		{
			crc_init(&crclow,&crchigh);
			for(i = 0; i < 1024; i++)
			{
				ReadFile(hFile, pWrite, 1, &dwBytesRead, NULL);
				crc_calc(&crclow,&crchigh,*(pWrite++));
			}
			*(pWrite++) = crchigh;
			*(pWrite++) = crclow;
		}

		dwFilesize = dwFilesize + 20 + ((dwFilesize/1024) * 2);
		CloseHandle(hFile);
	}
	else
	{
		// Read the file data into the file buffer
		ReadFile(hFile, pWrite, dwFilesize, &dwBytesRead, NULL);
		CloseHandle(hFile);
		if(dwBytesRead != dwFilesize)
		{
			AfxMessageBox("Error reading file.");
			return;
		}
	}

	int nNumK = dwFilesize / 1024;

	if(dwFilesize % 1024)
	{
		nNumK++;
	}

	m_cDLProgress.SetRange(0,nNumK);
	m_cDLProgress.SetStep(1);
	m_cDLProgress.SetPos(0);
	m_cDLProgress.ShowWindow(SW_SHOW);


	m_bSending = TRUE;
	m_bStopSending = FALSE;

	serStats *pStats;
	
	pStats = new serStats;
	pStats->pBuffer = pBuffer;
	pStats->dwFilesize = dwFilesize;

	m_cSend.SetWindowText("Stop");

	AfxBeginThread(SerialDownloadThread,pStats);
}

BOOL CCC2serDlg::OpenComPort()
{
	UpdateData();
	m_hComPort = CreateFile(m_sPort, GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
	if(m_hComPort == INVALID_HANDLE_VALUE)
	{
		AfxMessageBox("Unable to open COM port.");
		return FALSE;
	}

	if(!GetCommState(m_hComPort, &m_dcbComSettings))
	{
		AfxMessageBox("Unable to get status of COM port!");
		CloseHandle(m_hComPort);
		return FALSE;
	}

	m_dcbComSettings.Parity = NOPARITY;
	m_dcbComSettings.StopBits = ONESTOPBIT;
	m_dcbComSettings.ByteSize = 8;
	m_dcbComSettings.BaudRate = atoi(m_sBaudrate);
	
	if(!SetCommState(m_hComPort, &m_dcbComSettings))
	{
		CString sMessage;
		sMessage.Format("Unable to set COM port to %d/N81!", m_dcbComSettings.BaudRate);
		AfxMessageBox(sMessage);
		CloseHandle(m_hComPort);
		m_hComPort = NULL;
		return FALSE;
	}

	m_dwComMask = EV_TXEMPTY | EV_BREAK | EV_ERR;

	if(!SetCommMask(m_hComPort, m_dwComMask))
	{
		AfxMessageBox("Unable to set COM port event mask!");
		CloseHandle(m_hComPort);
		m_hComPort = NULL;
		return FALSE;
	}
	
	if(!SetupComm(m_hComPort, WriteBufferSize, WriteBufferSize))
	{
		AfxMessageBox("Unable to set buffer sizes!");
		CloseHandle(m_hComPort);
		m_hComPort = NULL;
		return FALSE;
	}
	m_bComPortOpen = TRUE;
	return TRUE;
}



BOOL CCC2serDlg::CloseComPort()
{
/*	if(!SetCommMask(m_hFile, m_nOldMask))
	{
		AfxMessageBox("Unable to reset comm port event mask!");
		return;
	}

	if(!SetCommState(m_hFile, &m_dcbOldCommSettings))
	{
		AfxMessageBox("Unable to reset comm port settings!");
		return;
	}*/
	CloseHandle(m_hComPort);
	m_hComPort = NULL;
	m_bComPortOpen = FALSE;
	return TRUE;
}

void CCC2serDlg::OnRadioAuto() 
{
	// TODO: Add your control notification handler code here
	m_cBankswitch.EnableWindow(TRUE);
	m_cStartup.EnableWindow(TRUE);
}

void CCC2serDlg::OnRadioManual() 
{
	// TODO: Add your control notification handler code here
	m_cBankswitch.EnableWindow(FALSE);
	m_cStartup.EnableWindow(FALSE);
}


void CCC2serDlg::SaveSettings()
{
	HKEY hKey;
	DWORD data;

	// Open the registry key 
	RegCreateKeyEx(HKEY_CURRENT_USER, TEXT("Software\\CuttleCart2\\CC2Ser"), 0, NULL, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, NULL, &hKey, NULL);
	if (RegOpenKeyEx(HKEY_CURRENT_USER, TEXT("Software\\CuttleCart2\\CC2Ser"), 0, KEY_ALL_ACCESS, &hKey)==ERROR_SUCCESS)
	{
		// Store COM Port
		 RegSetValueEx(hKey, TEXT("ComPort"), 0, REG_SZ, (const BYTE*)LPCTSTR(m_sPort), m_sPort.GetLength()+1);

		// Store Baud Rate
		RegSetValueEx(hKey, TEXT("BaudRate"), 0, REG_SZ, (const BYTE*)LPCTSTR(m_sBaudrate), m_sBaudrate.GetLength()+1);

		// Store Bankswitch
		RegSetValueEx(hKey, TEXT("Bankswitch"), 0, REG_SZ, (const BYTE*)LPCTSTR(m_sBankswitch), m_sBankswitch.GetLength()+1);

		// Store Startup
		RegSetValueEx(hKey, TEXT("Startup"), 0, REG_SZ, (const BYTE*)LPCTSTR(m_sStartup), m_sStartup.GetLength()+1);
	
		// Store Auto/Manual Setting
		data = m_cRadioAuto.GetCheck();
		RegSetValueEx(hKey, TEXT("AutoMode"), 0, REG_DWORD, (const BYTE*)&data, sizeof(data));

		/* Close the registry key */
		RegCloseKey(hKey);
	}


}

// Load settings from the registry 
void CCC2serDlg::LoadSettings()
{
	HKEY hKey;
	DWORD data;
	BYTE buffer[100];
	DWORD buffersize = 100;

	// Open the registry key 
//	RegCreateKeyEx(HKEY_CURRENT_USER, TEXT("Software\\CuttleCart\\PlayBin"), 0, NULL, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, NULL, &hKey, NULL);
	if (RegOpenKeyEx(HKEY_CURRENT_USER, TEXT("Software\\CuttleCart2\\CC2Ser"), 0, KEY_ALL_ACCESS, &hKey)==ERROR_SUCCESS)
	{
		
		// Read the COM port setting
		if(ReadRegString(hKey, TEXT("ComPort"), buffer, buffersize))
		{
			if(strlen((char *)buffer) > 0)
			{
				int nIdx = m_cPort.FindStringExact(-1, LPTSTR(buffer));
				if(nIdx > -1)
				{
					m_cPort.SetCurSel(nIdx);
				}
			}
		}

		// Read the Baud rate setting
		if(ReadRegString(hKey, TEXT("BaudRate"), buffer, buffersize))
		{
			if(strlen((char *)buffer) > 0)
			{
				int nIdx = m_cBaudrate.FindStringExact(-1, LPTSTR(buffer));
				if(nIdx > -1)
				{
					m_cBaudrate.SetCurSel(nIdx);
				}
			}
		}

		// Read the bankswitch setting
		if(ReadRegString(hKey, TEXT("Bankswitch"), buffer, buffersize))
			m_cBankswitch.SetWindowText((LPTSTR)buffer);

		// Read the Startup setting
		if(ReadRegString(hKey, TEXT("Startup"), buffer, buffersize))
			m_cStartup.SetWindowText((LPTSTR)buffer);

		// Read Auto/Manual Setting
		if(ReadRegDWORD(hKey, TEXT("AutoMode"), &data))
		{
			if (data==1)
			{
				m_cRadioAuto.SetCheck(1);
				m_cRadioManual.SetCheck(0);
			}
			else
			{
				m_cRadioAuto.SetCheck(0);
				m_cRadioManual.SetCheck(1);
				m_cBankswitch.EnableWindow(FALSE);
				m_cStartup.EnableWindow(FALSE);
			}

		}
		else
		{
			m_cRadioAuto.SetCheck(1);	//Use Auto by default;
			m_cRadioManual.SetCheck(0);
		}
		//Close the registry key
		RegCloseKey(hKey);
	}
	else
	{ // If not read from registry, fill default values
		m_cRadioAuto.SetCheck(1);	//Set automode
		m_cPort.SetCurSel(0);	//Set first port
		m_cBaudrate.SetCurSel(4); //Set 57600
	}
}

/* Read a DWORD value from the registry */
static BOOL ReadRegDWORD(HKEY hKey, LPTSTR name, LPDWORD data)
{
	DWORD size=sizeof(*data);
	DWORD type;
	LONG result;

	/* Retrieve value from registry */
	result=RegQueryValueEx(hKey, name, NULL, &type, (BYTE*)data, &size);

	/* If error then return default value, else return retrieved data */
	if (result!=ERROR_SUCCESS) return FALSE;
	else return TRUE;
}

BOOL ReadRegString(HKEY hKey, LPTSTR name, BYTE *buffer, DWORD buffersize)
{
	DWORD type;
	LONG result;

	/* Retrieve value from registry */
	result=RegQueryValueEx(hKey, name, NULL, &type, buffer, &buffersize);

	/* If error then return default value, else return retrieved data */
	if (result!=ERROR_SUCCESS) return FALSE;
	else return TRUE;
}


void CCC2serDlg::OnClose() 
{
	// TODO: Add your message handler code here and/or call default
	UpdateData();
	SaveSettings();	
	CDialog::OnClose();
}


