/* FIND.C: Generate a list of files that match a given filespec in a directory. */

#include <stdio.h>
#include <string.h>
#include <time.h>
#include <stdlib.h>
#include "queue.h"
#include "find.h"
#ifndef __unix__
	#include <io.h> 
#elif defined __FreeBSD__
	#include <sys/types.h>
/*	#include <machine/cpufunc.h> */
     #include <dirent.h>
	#include <sys/stat.h>
#else
	#include <dirent.h>
	#include <sys/types.h>
	#include <sys/stat.h>
	#include <unistd.h>
#endif

#ifndef __unix__
/* Windows Version*/
int myGlob( char *globString, struct qnode **fileNameQ, int *fileCount )
{
    struct FINDDATA_TYPE c_file;
    long hFile;
    char full_path_buffer[_MAX_DRIVE+_MAX_DIR+_MAX_FNAME+_MAX_EXT];
    char drive[_MAX_DRIVE];
    char dir[_MAX_DIR];
    char fname[_MAX_FNAME];
    char ext[_MAX_EXT];

    if (strchr(globString,'+') != NULL)
    {
        *fileNameQ = addq(*fileNameQ, globString, fileCount);
        return 0;
    }
    _splitpath( globString, drive, dir, fname, ext );
#ifdef _WIN32
    if( (hFile = _findfirst( globString, &c_file )) == -1L )
#else
    if( (hFile = findfirst( globString, &c_file, 0 )) == -1L )
#endif
       printf( "No files matching %s in current directory!\n", globString );
   else
   {
            if (!(c_file.FFATTRIB & FA_DIREC))
	    {
		/*sprintf(full_path_buffer,"%s%s%s",drive,dir,c_file.FFNAME);*/
                *fileNameQ = addq(*fileNameQ, c_file.FFNAME, fileCount);
			}
/*              printf( " %-12s\n", c_file.FFNAME); */

            /* Find the rest of the .c files */
#ifdef _WIN32
            while( _findnext( hFile, &c_file ) == 0 )
#else
            while( findnext( &c_file ) == 0 )
#endif
            {
                if (!(c_file.FFATTRIB & FA_DIREC))
		{
		    /*sprintf(full_path_buffer,"%s%s%s",drive,dir,c_file.FFNAME);*/
                    *fileNameQ = addq(*fileNameQ, c_file.FFNAME, fileCount);
				}
/*                  printf( " %-12s\n", c_file.FFNAME);*/
            }
#ifdef _WIN32
       _findclose( hFile );
#endif
/*     qprint(fileNameQ); */
   }
   return 0;
}

#else
/*linux version
 * Pretty much the standard example of scandir
 */
int myGlob( char *globString, struct qnode **fileNameQ, int *fileCount )
{
	struct dirent **namelist;
	int n;
	int cnt=0;
	struct stat fstat;

	n = scandir(".", &namelist, 0, alphasort);
	if (n < 0)
		perror("Invalid directory..");
	else
	{
		while(n--)
		{
			stat(namelist[n]->d_name,&fstat); /* Get file stat */

			/* Only process regular files (no directories) */
			if(S_ISREG(fstat.st_mode))
			{
				cnt++;
 				*fileNameQ = addq(*fileNameQ, namelist[n]->d_name, fileCount);
			}
			free(namelist[n]);
		}
		free(namelist);
	}
	if(cnt==0)
		printf( "No files matching *.BIN/*.bin in current directory!\n");
	return 0;
}

#endif

