/* makemenu.c*/
/*

   Poorly hacked from Bob Colbert's Makewav 4.3 by Chad Schell

   released to the public domain

   The author assumes no responsibility for any damage caused by the use or
   posession of this program.  USE AT YOUR OWN RISK!!!

*/

#include <ctype.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include <sys/stat.h>
#include "queue.h"
#include "find.h"
#include "romdb.h"


#ifdef __linux__
#elif defined __FreeBSD__
	#include <sys/types.h>
	#include <sys/stat.h>
#else
	#include <io.h>
	#include <conio.h>
	#include <direct.h>
#endif

#define CRC32_REV 0xA0000001    /* CRC-32 polynomial reversed */

#define TAB_WIDTH 8

unsigned long crc;         /* holds accumulated CRC */
unsigned long crctab[256];     /* table to help CRC calculation */

struct parmFlags
{
    int     binFileCount;
    struct   qnode *binFileQ;
};

int romentry_cmp_title(const void* a, const void* b);
void output_cc2_entry(FILE *of, struct romentry const *ent);
void output_txt_entry(FILE *of, struct romentry const *ent);
void pretty_print_field(FILE *of, const char *s, size_t field_width);

/* This only checks if the file/dir exist. */
int FileExist(const char* FileName)
{
   struct stat my_stat;
   return (stat(FileName, &my_stat) == 0);
}

int IsDirectory(const char* FileName)
{
   struct stat my_stat;
   if (stat(FileName, &my_stat) != 0) return 0;
   return ((my_stat.st_mode & S_IFDIR) != 0);
}

int MakeDirectory(const char* FileName)
{
#ifdef __unix__
	return mkdir(FileName, 0777);
#else
	return _mkdir(FileName);
#endif
}

/*
** used for generating the CRC lookup table
*/

unsigned long crcrevhware(unsigned long data, unsigned long genpoly, unsigned long accum)
{
  int i;
  data <<= 1;
  for (i=8;i>0;i--) {
    data >>= 1;
    if ((data ^ accum) & 1)
      accum = (accum >> 1) ^ genpoly;
    else
      accum >>= 1;
    }
  return(accum);
}


/*
** init the CRC lookup table
*/

void init_crc(void)
{
  int i;
  for (i=0;i<256;i++)
    crctab[i] = crcrevhware(i,CRC32_REV,0);
}


/*
** update CRC
*/

void ucrc(unsigned char data)
{
   crc = (crc >> 8) ^ crctab[(crc ^ data) & 0xff];
}

int filename_extenstion_is(const char *name, const char *ext)
{
	const char *p = strrchr(name, '.');

	if (p)
	{
		size_t i;

		++p;

		for (i = 0; toupper(p[i]) == toupper(ext[i]); ++i)
		{
			if (!p[i])
			{
				return 1;
			}
		}
	}

	return 0;
}

int main(int argc, char** argv)
{
	long fsize;

	struct parmFlags parms;
	char newFileName[256];
	char Wildcard[] = "*";
	struct romentry const ** Listed;
	int *ListedIndex, Index;
	int ListedCount;
	char input;
	FILE *binFile, *TxtOutputFile, *CC2OutputFile;
	unsigned char fileBuffer[512*1024];
	struct romdb *RomDb;
	char *InputFileName = "CC2ROMDB.TXT";
	char *TxtOutputFileName = "MENU.TXT";
	char *CC2OutputFileName = "MENU.CC2";
//	void (*output_fn)(FILE *of, struct romentry const *ent);
	int i;

	/* Parse command line options.
	   Only valid option was filename, which has been hardcoded for now.
	*/
/*	for (i = 1; i < argc; ++i)
	{
		if ((argv[i][0] == '-') && (argv[i][1] != '-'))
		{
			const char opt = argv[i][1];

			if (opt == 'o')
			{
				OutputFileName = argv[++i];
				continue;
			}
		}
		else if ((argv[i][0] == '-') && (argv[i][1] == '-'))
		{

		}
		else
		{

		}

		printf("Unrecognized option %s\n", argv[i]);
	}
*/

	/* Choose the output format based on the file name extension. 
	   Changed to always call both output functions
	*/
/*
	if (filename_extenstion_is(OutputFileName, "CC2"))
	{
		output_fn = output_cc2_entry;
	}
	else
	{
		output_fn = output_txt_entry;
	}
*/

	TxtOutputFile = fopen(InputFileName, "r");
	if(TxtOutputFile == NULL)
	{
		printf("Error, unable to open input file %s.\n",
		       InputFileName);
		goto ExitWithError;
	}

	RomDb = romdb_load(TxtOutputFile);
	fclose(TxtOutputFile);
	TxtOutputFile = NULL;

	if (!RomDb)
	{
		/* romdb_load() should have printed the error */
		goto ExitWithError;
	}

	printf("This program will search the current directory for Atari ROMs\n");
	printf("that it recognizes and move them to the subdirectory \"GAMES\" (which\n");
	printf("it will create if it does not already exist.)  The ROMs will be renamed\n");
	printf("into 8.3 format for use with the Cuttle Cart 2.  The original ROMs and any\n");
	printf("duplicate ROMs will be deleted.\n");
	printf("\nPlease backup your ROMs to another directory before proceeding.\n\n");
	printf("Proceed? (Y/N): ");

#ifdef __unix__
	/* This will block until return is pressed. */
	input = getchar();
#else
	/* Under windows this does not require a return. */
	input = _getch();
#endif

	if(toupper(input) != 'Y')
		return 0;

	parms.binFileCount = 0;
	parms.binFileQ = NULL;

	myGlob(Wildcard, &parms.binFileQ, &parms.binFileCount);

	if(FileExist("GAMES"))
	{
		if(IsDirectory("GAMES"))
		{
			printf("Warning:  Games directory already exists.\n");
			/* Give user a choice here. */
		}
		else
		{
			printf("Error: GAMES is not a directory.");
			goto ExitWithError;
		}
	}
	else
	{
		if(MakeDirectory("GAMES"))
		{
			printf("Error, unable to created GAMES directory.\n");
			goto ExitWithError;
		}
	}

	if((TxtOutputFile = fopen(TxtOutputFileName,"w"))==NULL)
	{
		printf("Error, unable to create output file %s.\n",
		       TxtOutputFileName);
		goto ExitWithError;
	}
	if((CC2OutputFile = fopen(CC2OutputFileName,"w"))==NULL)
	{
		printf("Error, unable to create output file %s.\n",
		       CC2OutputFileName);
		goto ExitWithError;
	}
	init_crc();
	Listed = malloc(romdb_size(RomDb) * sizeof(Listed[0]));
	if(Listed == NULL)
	{
		printf("Error:  Unable to allocate check list RAM\n");
		goto ExitWithError;
	}
	memset(Listed, 0, romdb_size(RomDb) * sizeof(Listed[0]));
	ListedIndex = malloc(romdb_size(RomDb) * sizeof(int));
	if(ListedIndex == NULL)
	{
		printf("Error:  Unable to allocate check list RAM\n");
		goto ExitWithError;
	}
	memset(ListedIndex, 0, romdb_size(RomDb) * sizeof(int));
	ListedCount = 0;

	for ( ;
	      parms.binFileQ != NULL;
	      parms.binFileQ = delq(parms.binFileQ))
	{
		const char *const filename = &parms.binFileQ->fileName[0];

		struct romentry const *ent;
		int i;

		binFile = fopen(filename,"rb");
		if (binFile == NULL)
		{
			printf("ERROR: unable to open .bin file %s\n",
			       filename);
			continue;
		}

		fseek(binFile,0,SEEK_END);
		fsize = ftell(binFile);
		fseek(binFile,0,SEEK_SET);
		if(fsize > 512*1024)
		{
			printf("Error:  File %s is too large, skipping.\n",
			       filename);
			fclose(binFile);
			continue;
		}

		fread(fileBuffer,fsize,1,binFile);
		fclose(binFile);

		crc = 0;
		for (i=0; i<fsize; i++)
			ucrc(fileBuffer[i]);

		ent = romdb_find_crc(RomDb, crc, &Index);
		if(!ent)
		{
			printf("No match for file %s.\n",filename);
			continue;
		}

#ifdef __unix__
		snprintf(newFileName, sizeof(newFileName),
			 "GAMES/%s.BIN", ent->RomName);
#else
		sprintf(newFileName, "GAMES\\%s.BIN", ent->RomName);
#endif
		if(FileExist(newFileName))
		{
			remove(newFileName);	/* Erase old file */
		}
		/*7800 Crossbow and Alien Brigade do not work
		  as they are most commonly distributed.  The
		  extra 16K bank needs to be moved from the
		  start to the end of the ROM*/
		if((crc == 1936321014) || (crc == 350122756))
		{
			binFile = fopen(filename, "rb+");
			if (binFile == NULL)
			{
				printf("ERROR: unable to open .bin file %s\n",
				       filename);
				fclose(TxtOutputFile);
				fclose(CC2OutputFile);
				goto ExitWithError;
			}
			fwrite(fileBuffer+(16*1024),(128*1024),1,binFile);
			fwrite(fileBuffer,(16*1024),1,binFile);
			fclose(binFile);
		}
		rename(filename, newFileName);

		/* An entry should appear in the menu if it has a ROM
		 * file and bankswitch and startup files.  Entries
		 * that have a ROM file but no bankswitch or startup
		 * files represent Supercharger loads that do not need
		 * their own menu entries. */
		if (ent->RomName[0] && ent->Bankswitch[0] && ent->Startup[0])
		{
			if(ListedIndex[Index] == 0)	/*If ROM not already found*/
			{
				Listed[ListedCount++] = ent;	/*List it*/
				ListedIndex[Index] = 1;			/*Mark it as listed.*/
			}
		}
	}

	/* Sort by title. */
	qsort(Listed, ListedCount, sizeof(Listed[0]), romentry_cmp_title);

	/* Print all entries that were found during the search. */
	for (ListedCount=0;
	     ListedCount < romdb_size(RomDb);
	     ListedCount++)
	{
		const struct romentry *const ent = Listed[ListedCount];
		if (!ent)
		{
			break;
		}

		output_txt_entry(TxtOutputFile, ent);
		output_cc2_entry(CC2OutputFile, ent);
	}

	fclose(TxtOutputFile);
	fclose(CC2OutputFile);
	return 0;

 ExitWithError:

#ifndef __unix__
	/* Pause so people running this in a DOS window will be able
	 * to read the error before the window closes. */
	printf("Press any key to continue.\n");
	_getch();
#endif

	return 1;
}

int romentry_cmp_title(const void* a, const void* b)
{
	const struct romentry *const left = *(const struct romentry**)a;
	const struct romentry *const right = *(const struct romentry**)b;

	return strcmp(left->Name, right->Name);
}

void output_cc2_entry(FILE *of, struct romentry const *ent)
{
	fprintf(of, "%-*s%-*s%-*s%-*s",
		MAX_GAME_NAME_LEN, ent->Name,
		MAX_FILE_NAME_LEN, ent->RomName,
		MAX_FILE_NAME_LEN, ent->Bankswitch,
		MAX_FILE_NAME_LEN, ent->Startup);
}

void output_txt_entry(FILE *of, struct romentry const *ent)
{
	pretty_print_field(of, ent->Name, MAX_GAME_NAME_LEN);
	fputc('\t', of);

	pretty_print_field(of, ent->RomName, MAX_FILE_NAME_LEN);
	fputc('\t', of);

	pretty_print_field(of, ent->Bankswitch, MAX_FILE_NAME_LEN);
	fputc('\t', of);

	pretty_print_field(of, ent->Startup, MAX_FILE_NAME_LEN);
	fputc('\n', of);
}

void pretty_print_field(FILE *of, const char *s, size_t field_width)
{
	if (s)
	{
		size_t len = strlen(s);

		if (len)
		{
			fputs(s, of);

			for (len = strlen(s);
			     len < field_width;
			     len = (len - (len % TAB_WIDTH)) + TAB_WIDTH)
			{
				fputc('\t', of);
			}

			return;
		}
	}

	fputs("-\t", of);
}
