#ifndef MAKEMENU_H
#define MAKEMENU_H

enum bankswitch_mode
{
	BS_NA=0,	/* not applicable */
	BS_2K,		/* 2600 2K Non-Bankswitched Cart */
	BS_4K,		/* 2600 4K Non-Bankswitched Cart */
	BS_3F,		/* 2600 Tigervision 3F Bankswitching */
	BS_7800_8K,	/* 7800 8K Non-Bankswitched Cart */
	BS_7800_16K,	/* 7800 16K Non-Bankswitched Cart */
	BS_7800_32K,	/* 7800 32K Non-Bankswitched Cart */
	BS_7800_48K,	/* 7800 48K Non-Bankswitched Cart */
	BS_78POKEY,	/* 7800 48K 32K Non-Bankswitched Cart w/POKEY */
	BS_78SC_BIG,	/* 7800 Supercart w/144K ROM */
	BS_78SC_LOW,	/* 7800 Supercart w/128K ROM & bank6 mapped to $4000 */
	BS_78SC_POK,	/* 7800 Supercart w/POKEY */
	BS_78SC_R16,	/* 7800 Supercart w/128K ROM and 16K RAM */
	BS_78SC_R8K,	/* 7800 Supercart w/128K ROM and 8K RAM */
	BS_78SC_SM,	/* 7800 Supercart w/64K ROM */
	BS_78SCR8SM,	/* 7800 Supercart w/64K ROM and 8K RAM */
	BS_ABS78,	/* 7800 Absolute Bankswitching */
	BS_ACT78,	/* 7800 Activision Bankswitching */
	BS_CV,		/* 2600 Commavid Bankswitching */
	BS_E0,		/* 2600 Parkervision E0 Bankswitching */
	BS_E7,		/* 2600 M-Network E7 Bankswitching w/RAM */
	BS_F4,		/* 2600 F4 Bankswitching */
	BS_F4SC,	/* 2600 F4 Bankswitching w/Superchip */
	BS_F6,		/* 2600 F6 Bankswitching w/Superchip */
	BS_F6SC,	/* 2600 F6 Bankswitching w/Superchip */
	BS_F8,		/* 2600 F8 Bankswitching */
	BS_F8R,		/* 2600 F8 Bankswitching w/Banks reversed */
	BS_F8SC,	/* 2600 F8 Bankswitching w/Superchip */
	BS_FA,		/* 2600 CBS Electronics FA Bankswitching w/RAM */
	BS_FANR,	/* 2600 CBS Electronics FA Bankswitching w/o RAM */
	BS_FE,		/* 2600 Activision FE Bankswitching */
	BS_HSC_16K,	/* 7800 16K Game w/High Score Cart Support */
	BS_HSC_32K,	/* 7800 32K Game w/High Score Cart Support */
	BS_HSC_48K,	/* 7800 32K Game w/High Score Cart Support */
	BS_MEGABOY,	/* 2600 Dynacom Megaboy Bankswitching */
	BS_SC,		/* 2600 Self-Loading Supercharger Bankswitching */
	BS_UA		/* 2600 UA Bankswitching */
};

/* N.B. These must be in the same order as enum bankswitch_mode */
const char *const BankswitchModeNames[] = {
	"",
	"2K",
	"4K",
	"3F",
	"7800_8K",
	"7800_16K",
	"7800_32K",
	"7800_48K",
	"78POKEY",
	"78SC_BIG",
	"78SC_LOW",
	"78SC_POK",
	"78SC_R16",
	"78SC_R8K",
	"78SC_SM",
	"78SCR8SM",
	"ABS78",
	"ACT78",
	"CV",
	"E0",
	"E7",
	"F4",
	"F4SC",
	"F6",
	"F6SC",
	"F8",
	"F8R",
	"F8SC",
	"FA",
	"FANR",
	"FE",
	"HSC_16K",
	"HSC_32K",
	"HSC_48K",
	"MEGABOY",
	"SC",
	"UA"
};

enum startup_code
{
	SC_NA=0,	/* not applicable */
	SC_78BIOS,	/* call the 7800 BIOS */
	SC_HSC,		/* 7800 with High Score Cart */
	SC_SC,		/* Starpath Supercharger games */
	SC_F6BANK0,	/* F6 games that must start in Bank 0 */
	SC_F8BANK1	/* F8 games that must start in Bank 1 */
};

/* N.B. These must be in the same order as enum startup_code */
const char *const StartupCodeNames[] = {
	"",
	"78BIOS",
	"HSC",
	"SC",
	"F6BANK0",
	"F8BANK1"
};

struct romentry
{
	unsigned char*	Name;
	unsigned char*	RomName;
	unsigned char*	InstName;
	enum bankswitch_mode	Bankswitch;
	enum startup_code	Startup;
	int		InMenu;
	unsigned long	CRC;
};

const struct romentry RomList[] = {
{"Ace Of Aces - 7800",
 "ACE78", "ACE78", BS_78SC_LOW, SC_78BIOS, 1, 0x04bbdc71},
{"Alien Brigade - 7800",
 "ALIEN78", "ALIEN78", BS_78SC_BIG, SC_78BIOS, 1, 0x15ef9ec2},
{"Alien Brigade - 7800",
 "ALIEN78", "ALIEN78", BS_78SC_BIG, SC_78BIOS, 1, 0x7369e9f6},
{"Asteroids - 7800",
 "ASTR78", "ASTR78", BS_HSC_16K, SC_HSC, 1, 0x53a7468c},
{"Ballblazer - 7800",
 "BALLBLZR", "BALLBLZR", BS_78POKEY, SC_78BIOS, 1, 0x10d821ea},
{"Barnyard Blaster - 7800",
 "BARNYD", "BARNYD", BS_78SC_LOW, SC_78BIOS, 1, 0xcc4d2e4a},
{"Basketbrawl - 7800",
 "BSKTBRWL", "BSKTBRWL", BS_78SC_LOW, SC_78BIOS, 1, 0x52f7a63c},
{"Centipede - 7800",
 "CENT78", "CENT78", BS_HSC_16K, SC_HSC, 1, 0x7282482f},
{"Choplifter - 7800",
 "CHOPLFTR", "CHOPLFTR", BS_7800_32K, SC_78BIOS, 1, 0x5156726c},
{"Color (demo) - 7800",
 "COLOR78", "COLOR78", BS_7800_8K, SC_78BIOS, 1, 0x15e6026b},
{"Commando - 7800",
 "COMM78", "COMM78", BS_78SC_POK, SC_78BIOS, 1, 0x30be5f73},
{"Cracked - 7800",
 "CRACK78", "CRACK78", BS_78SC_LOW, SC_78BIOS, 1, 0xa5225d53},
{"Crossbow - 7800",
 "CRSSBW78", "CRSSBW78", BS_78SC_BIG, SC_78BIOS, 1, 0x0d13e045},
{"Crossbow - 7800",
 "CRSSBW78", "CRSSBW78", BS_78SC_BIG, SC_78BIOS, 1, 0x14de7304},
{"Dark Chambers - 7800",
 "DRKCH78", "DRKCH78", BS_78SC_LOW, SC_78BIOS, 1, 0x4ad7b8bc},
{"Desert Falcon - 7800",
 "DESRT78", "DESRT78", BS_7800_48K, SC_78BIOS, 1, 0x82d1721a},
{"Dig Dug - 7800",
 "DIGDUG78", "DIGDUG78", BS_HSC_16K, SC_HSC, 1, 0x86cd3958},
{"Donkey Kong - 7800",
 "DK78", "DK78", BS_7800_48K, SC_78BIOS, 1, 0x7756ef11},
{"Donkey Kong Jr - 7800",
 "DKJR78", "DKJR78", BS_7800_48K, SC_78BIOS, 1, 0xc7a58f83},
{"Double Dragon - 7800",
 "DOUBLE78", "DOUBLE78", BS_ACT78, SC_78BIOS, 1, 0xa2b349bb},
{"F-18 Hornet - 7800",
 "F18_78", "F18_78", BS_ABS78, SC_78BIOS, 1, 0x9d78ea01},
{"Fatal Run - 7800",
 "FATAL78", "FATAL78", BS_78SC_LOW, SC_78BIOS, 1, 0xab03db56},
{"Fight Night - 7800",
 "FIGHT78", "FIGHT78", BS_78SC_LOW, SC_78BIOS, 1, 0x71851a3f},
{"Food Fight - 7800",
 "FOOD78", "FOOD78", BS_HSC_32K, SC_HSC, 1, 0xea2dbf11},
{"Galaga - 7800",
 "GALAGA78", "GALAGA78", BS_HSC_32K, SC_HSC, 1, 0x2892f0da},
{"Hat Trick - 7800",
 "HAT78", "HAT78", BS_7800_48K, SC_78BIOS, 1, 0x5e88c745},
{"Ikari Warriors - 7800",
 "IKARI78", "IKARI78", BS_78SC_LOW, SC_78BIOS, 1, 0x3280c702},
{"Impossible Mission - 7800",
 "IMPOSS78", "IMPOSS78", BS_78SC_R16, SC_78BIOS, 1, 0xa18c4274},
{"Jinks - 7800",
 "JINKS78", "JINKS78", BS_78SC_R16, SC_78BIOS, 1, 0xa162e7e8},
{"Joust - 7800",
 "JOUST78", "JOUST78", BS_HSC_32K, SC_HSC, 1, 0xf3444a12},
{"Karateka - 7800",
 "KARTKA78", "KARTKA78", BS_7800_48K, SC_78BIOS, 1, 0x7a7bff10},
{"Klax (proto) - 7800",
 "KLAX78", "KLAX78", BS_78SC_LOW, SC_78BIOS, 1, 0xcd41aabf},
{"Kung-Fu Master - 7800",
 "KUNGFU78", "KUNGFU78", BS_7800_32K, SC_78BIOS, 1, 0x17daf056},
{"Mario Brothers - 7800",
 "MARIO78", "MARIO78", BS_7800_48K, SC_78BIOS, 1, 0x63de72ad},
{"Mat Mania - 7800",
 "MATMAN78", "MATMAN78", BS_78SC_LOW, SC_78BIOS, 1, 0xa8a8f2fb},
{"Mean 18 Ultimate [ - 7800",
 "MEAN18", "MEAN18", BS_78SC_LOW, SC_78BIOS, 1, 0xf19105c1},
{"Meltdown - 7800",
 "MELTDN78", "MELTDN78", BS_78SC_LOW, SC_78BIOS, 1, 0xdd2a1a57},
{"Midnight Mutants - 7800",
 "MIDMUT78", "MIDMUT78", BS_78SC_LOW, SC_78BIOS, 1, 0x19f34f6b},
{"Motor Psycho - 7800",
 "MOTOR78", "MOTOR78", BS_78SC_LOW, SC_78BIOS, 1, 0x735c5951},
{"Ms. Pac-Man - 7800",
 "MSPAC78", "MSPAC78", BS_HSC_16K, SC_HSC, 1, 0x8a276d55},
{"Ninja Golf - 7800",
 "NINJA78", "NINJA78", BS_78SC_LOW, SC_78BIOS, 1, 0x0a2a82aa},
{"One-on-One - 7800",
 "ONE78", "ONE78", BS_7800_48K, SC_78BIOS, 1, 0xe9fa80b9},
{"Pete Rose Baseball - 7800",
 "PETE78", "PETE78", BS_7800_32K, SC_78BIOS, 1, 0x2a505dcf},
{"Pitfighter (proto) - 7800",
 "PITFIT78", "PITFIT78", BS_78SC_SM, SC_78BIOS, 1, 0xadce2869},
{"Planet Smashers - 7800",
 "PLANET78", "PLANET78", BS_78SC_LOW, SC_78BIOS, 1, 0x8a73745b},
{"Pole Position II - 7800",
 "POLE278", "POLE278", BS_7800_32K, SC_78BIOS, 1, 0x5c56f63a},
{"Rampage - 7800",
 "RAM78", "RAM78", BS_ACT78, SC_78BIOS, 1, 0x4205d71c},
{"RealSports Baseball - 7800",
 "RSB78", "RSB78", BS_78SC_SM, SC_78BIOS, 1, 0xe0858316},
{"Robotron 2084 - 7800",
 "ROBO78", "ROBO78", BS_HSC_32K, SC_HSC, 1, 0xd4d766cc},
{"Scrapyard Dog - 7800",
 "SCRAP78", "SCRAP78", BS_78SC_LOW, SC_78BIOS, 1, 0xd544229b},
{"Sentinel (NTSC) - 7800",
 "SENT78", "SENT78", BS_78SC_LOW, SC_78BIOS, 1, 0xd464769d},
{"Summer Games - 7800",
 "SUMMR78", "SUMMR78", BS_78SC_R16, SC_78BIOS, 1, 0x88258776},
{"Super Huey - 7800",
 "HUEY78", "HUEY78", BS_7800_48K, SC_78BIOS, 1, 0x005c5c44},
{"Super Skateboardin' - 7800",
 "SKATE78", "SKATE78", BS_7800_32K, SC_78BIOS, 1, 0x1a8b0033},
{"Tank Command - 7800",
 "TANK78", "TANK78", BS_78SC_SM, SC_78BIOS, 1, 0x82f59044},
{"Test Cart - 7800",
 "TEST78", "TEST78", BS_7800_32K, SC_78BIOS, 1, 0x5ba3f2dd},
{"TitleMatch Pro Wrestling - 7800",
 "WRESTL78", "WRESTL78", BS_7800_32K, SC_78BIOS, 1, 0x1b8108cc},
{"Tomcat: F14 - 7800",
 "F14_78", "F14_78", BS_7800_32K, SC_78BIOS, 1, 0x17be439f},
{"Touchdown Football - 7800",
 "TDFOOT78", "TDFOOT78", BS_78SC_LOW, SC_78BIOS, 1, 0x7fffa782},
{"Tower Toppler - 7800",
 "TOWER78", "TOWER78", BS_78SCR8SM, SC_78BIOS, 1, 0xce734858},
{"Water Ski - 7800",
 "WATER78", "WATER78", BS_78SC_SM, SC_78BIOS, 1, 0x36a7b591},
{"Winter Games - 7800",
 "WINTER78", "WINTER78", BS_78SC_R16, SC_78BIOS, 1, 0x42e6e57e},
{"Xenophobe - 7800",
 "XENO78", "XENO78", BS_78SC_LOW, SC_78BIOS, 1, 0x3d84eda1},
{"Xevious - 7800",
 "XEV78", "XEV78", BS_HSC_32K, SC_HSC, 1, 0x9ad283e3},
{"3D Tic-Tac-Toe",
 "3DTIC", "3DTIC", BS_2K, SC_78BIOS, 1, 0xb98f339e},
{"Acid Drop",
 "ACIDNTSC", "ACIDNTSC", BS_F8, SC_78BIOS, 1, 0x7805bc6f},
{"Acid Drop (PAL)",
 "ACIDDROP", "ACIDDROP", BS_F8, SC_78BIOS, 1, 0xe5314b6c},
{"Adventure",
 "ADVENT", "ADVENT", BS_4K, SC_78BIOS, 1, 0x860db891},
{"Adventure Plus (hack)",
 "ADVPLUS", "ADVPLUS", BS_4K, SC_78BIOS, 1, 0x8fcf7310},
{"Adventures of TRON",
 "ADOFTRON", "ADOFTRON", BS_4K, SC_78BIOS, 1, 0xfbe1a93a},
{"Air Raid",
 "AIRRAID", "AIRRAID", BS_4K, SC_78BIOS, 1, 0x4f40a18e},
{"Air Raiders",
 "AIRRDRS", "AIRRDRS", BS_4K, SC_78BIOS, 1, 0xab0d571f},
{"Airlock",
 "AIRLOCK", "AIRLOCK", BS_4K, SC_78BIOS, 1, 0xd29ed96c},
{"Air-Sea Battle",
 "AIRSEA", "AIRSEA", BS_2K, SC_78BIOS, 1, 0x1750793f},
{"Alfred Challenge",
 "ALFCHLNG", "ALFCHLNG", BS_4K, SC_78BIOS, 1, 0x9813b610},
{"Alien",
 "ALIEN", "ALIEN", BS_4K, SC_78BIOS, 1, 0xa7890826},
{"Allia's Quest",
 "ALLIA", "ALLIA", BS_4K, SC_78BIOS, 1, 0xf3519fa3},
{"Alligator People (Proto)",
 "ALLIGATR", "ALLIGATR", BS_4K, SC_78BIOS, 1, 0x8ab1aff5},
{"Alpha-Beam with Ernie",
 "ALPHABEM", "ALPHABEM", BS_F8, SC_78BIOS, 1, 0x9a1a860b},
{"Amidar",
 "AMIDAR", "AMIDAR", BS_4K, SC_78BIOS, 1, 0x73d8c9d0},
{"Apples and Dolls",
 "APPLES", "APPLES", BS_4K, SC_78BIOS, 1, 0xf58ddf00},
{"Aquaventure (Proto)",
 "AQUAVEN", "AQUAVEN", BS_F8, SC_78BIOS, 1, 0x173beed3},
{"Armour Ambush",
 "ARMORAMB", "ARMORAMB", BS_4K, SC_78BIOS, 1, 0x21ab497b},
{"Artillery Duel(PAL)",
 "ARTDUEL", "ARTDUEL", BS_F8, SC_78BIOS, 1, 0x99b6a2af},
{"Assault",
 "ASSAULT", "ASSAULT", BS_4K, SC_78BIOS, 1, 0x0dc7895e},
{"Asterix",
 "ATRXNTSC", "ATRXNTSC", BS_F8, SC_78BIOS, 1, 0xed93f95d},
{"Asteroids",
 "ASTEROID", "ASTEROID", BS_F8, SC_78BIOS, 1, 0xacdb6441},
{"Asteroids DC+ (hack)",
 "ASTHACK", "ASTHACK", BS_F8, SC_78BIOS, 1, 0x1a5a782c},
{"Astroblast",
 "ASTRBLST", "ASTRBLST", BS_4K, SC_78BIOS, 1, 0x0982ce85},
{"Astrowar",
 "ASTROWAR", "ASTROWAR", BS_4K, SC_78BIOS, 1, 0x1dd2bea2},
{"Atari Logo",
 "ATARLOGO", "ATARLOGO", BS_2K, SC_78BIOS, 1, 0x56733981},
{"Atari Salt 2.6 diagnostic",
 "ATARSALT", "ATARSALT", BS_4K, SC_78BIOS, 1, 0x6e8be263},
{"Atari Video Cube",
 "ATARVIDC", "ATARVIDC", BS_4K, SC_78BIOS, 1, 0x5de38031},
{"A-Team (Proto - Save Hannibal)",
 "ATEAM1", "ATEAM1", BS_F8, SC_78BIOS, 1, 0x36d88ac8},
{"A-Team (Proto - Save Murdock)",
 "ATEAM2", "ATEAM2", BS_F8, SC_78BIOS, 1, 0x984e0500},
{"Atlantis",
 "ATLANTIS", "ATLANTIS", BS_4K, SC_78BIOS, 1, 0x3de5c2e6},
{"Atlantis II (Contest Version)",
 "ATLANTS2", "ATLANTS2", BS_4K, SC_78BIOS, 1, 0x43cdcf13},
{"Bachelor Party",
 "BACHPRTY", "BACHPRTY", BS_4K, SC_78BIOS, 1, 0x8b232fbb},
{"Bachelorette Party",
 "BACHLTTE", "BACHLTTE", BS_4K, SC_78BIOS, 1, 0xd9c47532},
{"Backgammon",
 "BACKGMN", "BACKGMN", BS_4K, SC_78BIOS, 1, 0xe24e8139},
{"Bank Heist",
 "BANKHST", "BANKHST", BS_4K, SC_78BIOS, 1, 0x781cacb5},
{"Barnstorming",
 "BARNSTRM", "BARNSTRM", BS_4K, SC_78BIOS, 1, 0xc73738b7},
{"Basic Math",
 "BASMATH", "BASMATH", BS_2K, SC_78BIOS, 1, 0xd90f272d},
{"BASIC Programming",
 "BASPROG", "BASPROG", BS_4K, SC_78BIOS, 1, 0x98efb758},
{"Basketball",
 "BASKETBL", "BASKETBL", BS_2K, SC_78BIOS, 1, 0xf6c793fe},
{"Battlezone",
 "BATLZONE", "BATLZONE", BS_F8, SC_78BIOS, 1, 0xf7370634},
{"Beamrider",
 "BEAMRDER", "BEAMRDER", BS_F8, SC_78BIOS, 1, 0xd35fdb2b},
{"Beany Bopper",
 "BEANYBOP", "BEANYBOP", BS_4K, SC_78BIOS, 1, 0x262d7375},
{"Beat 'em and Eat 'em",
 "BEATEM", "BEATEM", BS_4K, SC_78BIOS, 1, 0xaf28b265},
{"Berenstein Bears",
 "BERANBRS", "BERANBRS", BS_F8, SC_78BIOS, 1, 0x0b63f9e3},
{"Bermuda",
 "BERMUDA", "BERMUDA", BS_4K, SC_78BIOS, 1, 0xabbabcfd},
{"Bermuda Triangle",
 "BERMUDAT", "BERMUDAT", BS_4K, SC_78BIOS, 1, 0xccd2d43e},
{"Berzerk",
 "BERZERK", "BERZERK", BS_4K, SC_78BIOS, 1, 0x70882147},
{"Berzerk-Voice Enhanced",
 "BERZRKVE", "BERZRKVE", BS_F6, SC_F6BANK0, 1, 0xc820ea0d},
{"Big Bird's Egg Catch",
 "BIGBIRD", "BIGBIRD", BS_F8, SC_78BIOS, 1, 0xf57c88c7},
{"Bionic Breakthru",
 "BIONCBRK", "BIONCBRK", BS_F8, SC_78BIOS, 1, 0x3183c019},
{"Blackjack",
 "BLACKJK", "BLACKJK", BS_2K, SC_78BIOS, 1, 0xd3fa0c42},
{"Blueprint",
 "BLUEPRNT", "BLUEPRNT", BS_F8, SC_78BIOS, 1, 0x16b1a362},
{"BMX Airmaster",
 "BMXAIR", "BMXAIR", BS_F6, SC_78BIOS, 1, 0x51af2d3d},
{"Bobby is Going Home",
 "BOBYNTSC", "BOBYNTSC", BS_4K, SC_78BIOS, 1, 0x73bfb4b3},
{"Boing!",
 "BOING", "BOING", BS_4K, SC_78BIOS, 1, 0x2c636eb6},
{"Boing26 Rob Kudla",
 "BOING26", "BOING26", BS_4K, SC_78BIOS, 1, 0xb5b7b416},
{"Bowling",
 "BOWLING", "BOWLING", BS_2K, SC_78BIOS, 1, 0xcaf2cbce},
{"Boxing",
 "BOXING", "BOXING", BS_2K, SC_78BIOS, 1, 0xa52b7e12},
{"Brain Games",
 "BRAIN", "BRAIN", BS_2K, SC_78BIOS, 1, 0x27ff9feb},
{"Breakout",
 "BREAKOUT", "BREAKOUT", BS_2K, SC_78BIOS, 1, 0x74946443},
{"Brick Kick",
 "BRIKKICK", "BRIKKICK", BS_4K, SC_78BIOS, 1, 0x82c6f7d1},
{"Bridge",
 "BRIDGE", "BRIDGE", BS_4K, SC_78BIOS, 1, 0x15a1299f},
{"Buck Rodgers",
 "BUCK", "BUCK", BS_F8, SC_78BIOS, 1, 0x5474d585},
{"Bugs",
 "BUGS", "BUGS", BS_4K, SC_78BIOS, 1, 0xd8c2d1d3},
{"Bugs Bunny (Proto)",
 "BUGSBUNY", "BUGSBUNY", BS_F8, SC_78BIOS, 1, 0x1c0102c6},
{"Bump 'n Jump",
 "BUMPNJMP", "BUMPNJMP", BS_E7, SC_78BIOS, 1, 0xd523e776},
{"Bumper Bash",
 "BUMPBASH", "BUMPBASH", BS_4K, SC_78BIOS, 1, 0x7a0d162d},
{"Burgertime",
 "BURGTIME", "BURGTIME", BS_E7, SC_78BIOS, 1, 0x24c35820},
{"Burning Desire",
 "BURNDES", "BURNDES", BS_4K, SC_78BIOS, 1, 0xbef9acef},
{"Cakewalk",
 "CAKEWALK", "CAKEWALK", BS_4K, SC_78BIOS, 1, 0x52440b41},
{"California Games",
 "CALGAMES", "CALGAMES", BS_F6, SC_78BIOS, 1, 0x0e2e6fb2},
{"Canyon Bomber",
 "CANBOMB", "CANBOMB", BS_2K, SC_78BIOS, 1, 0x4d5d81e5},
{"Carnival",
 "CARNIVAL", "CARNIVAL", BS_4K, SC_78BIOS, 1, 0x3355b6ee},
{"Casino",
 "CASINO", "CASINO", BS_4K, SC_78BIOS, 1, 0xbbf361b2},
{"Cathouse Blues",
 "CATHOUSE", "CATHOUSE", BS_4K, SC_78BIOS, 1, 0x75bd9195},
{"CatTrax (proto)",
 "CATTRAX", "CATTRAX", BS_4K, SC_78BIOS, 1, 0x4323a078},
{"Cavtron (demo)",
 "CAVTRON", "CAVTRON", BS_4K, SC_78BIOS, 1, 0xa513abb7},
{"Centipede",
 "CENTIPDE", "CENTIPDE", BS_F8, SC_78BIOS, 1, 0x3097e0eb},
{"Challange of Nexar",
 "NEXAR", "NEXAR", BS_4K, SC_78BIOS, 1, 0x0875ef34},
{"Challenge (PAL)",
 "CHALENGE", "CHALENGE", BS_4K, SC_78BIOS, 1, 0xbf0aac36},
{"Chase the Chuckwagon",
 "CHUCKWGN", "CHUCKWGN", BS_4K, SC_78BIOS, 1, 0xea815972},
{"Checkers",
 "CHECKERS", "CHECKERS", BS_2K, SC_78BIOS, 1, 0x5d0af7a5},
{"China Syndrome",
 "CHINASYN", "CHINASYN", BS_4K, SC_78BIOS, 1, 0x1cb28465},
{"Chopper Command",
 "CHOPCMD", "CHOPCMD", BS_4K, SC_78BIOS, 1, 0xbd96c985},
{"Chuck Norris Super Kicks",
 "CHUCKNOR", "CHUCKNOR", BS_F8, SC_78BIOS, 1, 0x103ebe05},
{"Circus Atari",
 "CIRCUS", "CIRCUS", BS_4K, SC_78BIOS, 1, 0x8cf289e1},
{"Circus Atari (USE JOYSTICK)",
 "CIRCUSJ", "CIRCUSJ", BS_4K, SC_78BIOS, 1, 0x82ea8168},
{"Clown Down Town (PAL)",
 "CLOWNDWN", "CLOWNDWN", BS_4K, SC_78BIOS, 1, 0x3b5146f6},
{"Coco Nuts",
 "COCONUTS", "COCONUTS", BS_4K, SC_78BIOS, 1, 0xcfc539e5},
{"Code Breaker",
 "CODEBRKR", "CODEBRKR", BS_2K, SC_78BIOS, 1, 0x33eab939},
{"Coke Wins!",
 "COKEWINS", "COKEWINS", BS_4K, SC_78BIOS, 1, 0xf861a4c8},
{"Col 'N' (PAL)",
 "COL_N", "COL_N", BS_4K, SC_78BIOS, 1, 0x38d3342b},
{"Color Demo",
 "COLRDEMO", "COLRDEMO", BS_4K, SC_78BIOS, 1, 0x5411cce8},
{"Colourbar Generator",
 "COLORBAR", "COLORBAR", BS_4K, SC_78BIOS, 1, 0xd80ac750},
{"Colours (demo)",
 "COLOURS", "COLOURS", BS_2K, SC_78BIOS, 1, 0xabc520d4},
{"Combat",
 "COMBAT", "COMBAT", BS_2K, SC_78BIOS, 1, 0x84116ca0},
{"Combat II (Proto)",
 "COMBAT2", "COMBAT2", BS_F8, SC_78BIOS, 1, 0x9b8bdd99},
{"Commando",
 "COMMANDO", "COMMANDO", BS_F6, SC_78BIOS, 1, 0x43f2d7b3},
{"Commando Raid",
 "CMDORAID", "CMDORAID", BS_4K, SC_78BIOS, 1, 0x2ba2e691},
{"Communist Mutants (demo)",
 "CMDEMO00", "CMDEMO00", BS_SC, SC_SC, 1, 0x257ce686},
{"Communist Mutants From Space",
 "COMMIE00", "COMMIE00", BS_SC, SC_SC, 1, 0x2b0e89bc},
{"Computer Chess (Proto)",
 "COMCHESS", "COMCHESS", BS_4K, SC_78BIOS, 1, 0xba300e51},
{"Concentration",
 "CONCENT", "CONCENT", BS_2K, SC_78BIOS, 1, 0xbb09444c},
{"Condor Attack",
 "CONDORAT", "CONDORAT", BS_4K, SC_78BIOS, 1, 0x0ab2ed98},
{"Confrontation",
 "CONFRONT", "CONFRONT", BS_4K, SC_78BIOS, 1, 0xfec87e0d},
{"Congo Bongo",
 "CNGOBNGO", "CNGOBNGO", BS_F8, SC_F8BANK1, 1, 0xf4036713},
{"Console Wars",
 "CONSOLE", "CONSOLE", BS_4K, SC_78BIOS, 1, 0x7a11cda5},
{"Cookie Monster Munch",
 "COOKIE", "COOKIE", BS_F8, SC_78BIOS, 1, 0xdcf49717},
{"Cosmic Ark",
 "COSMARK", "COSMARK", BS_4K, SC_78BIOS, 1, 0x70ed88e4},
{"Cosmic Ark (proto)",
 "COSMCAR2", "COSMAR2", BS_4K, SC_78BIOS, 1, 0xac009e3e},
{"Cosmic Commuter",
 "COSCOMUT", "COSCOMUT", BS_4K, SC_78BIOS, 1, 0x837d7fd3},
{"Cosmic Corridor",
 "COSMCCOR", "COSMCCOR", BS_4K, SC_78BIOS, 1, 0x05463707},
{"Cosmic Creeps",
 "COSMCRPS", "COSMCRPS", BS_4K, SC_78BIOS, 1, 0x8fa212f4},
{"Cosmic Swarm",
 "COSMSWRM", "COSMSWRM", BS_2K, SC_78BIOS, 1, 0xbf933de2},
{"Crack'ed (proto)",
 "CRACKED", "CRACKED", BS_F6SC, SC_78BIOS, 1, 0x8fb63eca},
{"Crackpots",
 "CRACKPOT", "CRACKPOT", BS_4K, SC_78BIOS, 1, 0x5a5009e2},
{"Crash Dive",
 "CRASHDVE", "CRASHDVE", BS_4K, SC_78BIOS, 1, 0x3437f382},
{"Crazy Climber",
 "CRZYCLMB", "CRZYCLMB", BS_F8, SC_78BIOS, 1, 0x16720c6b},
{"Crazy Valet",
 "CRZYVALT", "CRZYVALT", BS_4K, SC_78BIOS, 1, 0x7fd47371},
{"Criminal Pursuit",
 "CRIMPUR", "CRIMPUR", BS_4K, SC_78BIOS, 1, 0xd7036918},
{"Cross Force",
 "CROSFRCE", "CROSFRCE", BS_4K, SC_78BIOS, 1, 0x6e0ff3b5},
{"Crossbow",
 "CROSSBOW", "CROSSBOW", BS_F6, SC_78BIOS, 1, 0xdc3b6ef4},
{"Cruise Missile",
 "CRZMISLE", "CRZMISLE", BS_4K, SC_78BIOS, 1, 0xda73cae1},
{"Crypts of Chaos",
 "CRYPTS", "CRYPTS", BS_4K, SC_78BIOS, 1, 0x656a9c72},
{"Crystal Castles",
 "CRYSTALC", "CRYSTALC", BS_F6SC, SC_78BIOS, 1, 0x51f6f317},
{"Cubicolour",
 "CUBICOLR", "CUBICOLR", BS_4K, SC_78BIOS, 1, 0x7f7443dc},
{"Cubis",
 "CUBIS000", "CUBIS000", BS_SC, SC_SC, 1, 0xe4ad9bb1},
{"Custer's Revenge",
 "CUSREVNG", "CUSREVNG", BS_4K, SC_78BIOS, 1, 0x85ee3c67},
{"Dancing Baby (demo)",
 "BABY", "BABY", BS_3F, SC_78BIOS, 1, 0x0f535197},
{"Dark Cavern",
 "DARKCAV", "DARKCAV", BS_4K, SC_78BIOS, 1, 0xbbbb890a},
{"Dark Chambers",
 "DRKCHAM", "DRKCHAM", BS_F6SC, SC_78BIOS, 1, 0x00ba2d68},
{"Dark Mage",
 "DARKMAGE", "DARKMAGE", BS_F8, SC_78BIOS, 1, 0xb87a10b7},
{"Deadly Duck",
 "DEADDUCK", "DEADDUCK", BS_4K, SC_78BIOS, 1, 0x3ede5ed4},
{"Death Trap",
 "DEATHTRP", "DEATHTRP", BS_4K, SC_78BIOS, 1, 0x15d8e02b},
{"Decathlon",
 "DECATHLN", "DECATHLN", BS_FE, SC_78BIOS, 1, 0x7d23e780},
{"Defender",
 "DEFENDER", "DEFENDER", BS_4K, SC_78BIOS, 1, 0x6f79fab8},
{"Defender II",
 "DEFENDR2", "DEFENDR2", BS_F8SC, SC_78BIOS, 1, 0x6b07d014},
{"Demolition Herby",
 "DEMHERBY", "DEMHERBY", BS_4K, SC_78BIOS, 1, 0x1d12e8c1},
{"Demon Attack",
 "DEMONATK", "DEMONATK", BS_4K, SC_78BIOS, 1, 0xe5e657da},
{"Demons to Diamonds",
 "DEMNSDIA", "DEMNSDIA", BS_4K, SC_78BIOS, 1, 0x7e18d535},
{"Desert Falcon",
 "DSRTFLCN", "DSRTFLCN", BS_F6SC, SC_78BIOS, 1, 0xf7888b3e},
{"Dice Puzzle",
 "DICEPZLE", "DICEPZLE", BS_4K, SC_78BIOS, 1, 0xaebfd482},
{"Dig Dug",
 "DIGDUG", "DIGDUG", BS_F6SC, SC_78BIOS, 1, 0xa972c32b},
{"Dishaster",
 "DISHASTR", "DISHASTR", BS_4K, SC_78BIOS, 1, 0x57f730ee},
{"Dodge 'Em",
 "DODGEM", "DODGE_EM", BS_4K, SC_78BIOS, 1, 0xe66d96a0},
{"Dodge 'Em",
 "DODGE_EM", "DODGE_EM", BS_4K, SC_78BIOS, 1, 0x78265170},
{"Dolphin",
 "DOLPHIN", "DOLPHIN", BS_4K, SC_78BIOS, 1, 0x64dda20f},
{"Donald Duck's Speedboat (Proto)",
 "DONALDUK", "DONALDUK", BS_F8, SC_78BIOS, 1, 0xf5261f12},
{"Donkey Kong",
 "DONKYKNG", "DONKYKNG", BS_4K, SC_78BIOS, 1, 0x58f70b56},
{"Donkey Kong Jr.",
 "DKJR", "DKJR", BS_F8, SC_78BIOS, 1, 0x5904c34d},
{"DoomZerk",
 "DOOMZERK", "DOOMZERK", BS_4K, SC_78BIOS, 1, 0x38ef98af},
{"Double Dragon",
 "DBLDRGN", "DBLDRGN", BS_F6, SC_78BIOS, 1, 0x8fd51b6b},
{"Double Dunk",
 "DBLDUNK", "DBLDUNK", BS_F6, SC_78BIOS, 1, 0xc8a32cab},
{"Dragon Defender",
 "DRGNDFND", "DRGNDFND", BS_4K, SC_78BIOS, 1, 0x7117e8a9},
{"Dragon Fire",
 "DRGNFIRE", "DRGNFIRE", BS_4K, SC_78BIOS, 1, 0x41cba411},
{"Dragon Stomper (demo)",
 "DSDEMO00", "DSDEMO00", BS_SC, SC_SC, 1, 0x598c4172},
{"Dragon Stomper",
 "DSTOMP00", "DSTOMP00", BS_SC, SC_SC, 1, 0x5b631653},
{"Dragon Stomper Load 2",
 "DSTOMP04", "", BS_NA, SC_NA, 0, 0x0392a8e8},
{"Dragon Stomper Load 3",
 "DSTOMP05", "", BS_NA, SC_NA, 0, 0xf1e9f4dd},
{"Dragster",
 "DRAGSTER", "DRAGSTER", BS_2K, SC_78BIOS, 1, 0x71abf0ea},
{"Duck Shot (PAL)",
 "DUCKSHOT", "DUCKSHOT", BS_4K, SC_78BIOS, 1, 0x43e7b631},
{"Dukes of Hazzard (Proto)",
 "DUKES", "DUKES", BS_F6, SC_78BIOS, 1, 0x22535604},
{"Dukes of Hazzard2 (Proto)",
 "DUKES2", "DUKES2", BS_2K, SC_78BIOS, 1, 0xe791f31c},
{"Dumbo's Flying Circus (Proto)",
 "DUMBO", "DUMBO", BS_F8, SC_78BIOS, 1, 0xe75ea3d3},
{"E.T. The Extra-Terrestrial",
 "ET", "ET", BS_F8, SC_78BIOS, 1, 0xed5f7745},
{"Earth Dies Screaming",
 "EARTHDIE", "EARTHDIE", BS_4K, SC_78BIOS, 1, 0xb4201ba5},
{"EdTris",
 "EDTRIS", "EDTRIS", BS_4K, SC_78BIOS, 1, 0xc2cb83b1},
{"Eggomania",
 "EGGO", "EGGO", BS_4K, SC_78BIOS, 1, 0xd2d31b9f},
{"Elevator Action (Proto)",
 "ELEVATOR", "ELEVATOR", BS_F8SC, SC_F8BANK1, 1, 0x9b216f4c},
{"Eli's Ladder",
 "ELILADR", "ELILADR", BS_4K, SC_78BIOS, 1, 0x596a8c31},
{"Elk Attack",
 "ELKATK", "ELKATK", BS_F8, SC_78BIOS, 1, 0x7b7d94bb},
{"Encounter at L-5",
 "ENCNTRL5", "ENCNTRL5", BS_4K, SC_78BIOS, 1, 0x8fc7a660},
{"Enduro",
 "ENDURO", "ENDURO", BS_4K, SC_78BIOS, 1, 0x6c891c2a},
{"Entity (Proto)",
 "ENTITY", "ENTITY", BS_4K, SC_78BIOS, 1, 0xdf1fa26d},
{"Entombed",
 "ENTOMBED", "ENTOMBED", BS_4K, SC_78BIOS, 1, 0xd36c9159},
{"Escape..Mind Master (demo)",
 "MMDEMO00", "MMDEMO00", BS_SC, SC_SC, 1, 0xc4f25050},
{"Escape from the Mind Master",
 "MNDMST00", "MNDMST00", BS_SC, SC_SC, 1, 0x7b9a0f78},
{"Escape MM Load 2",
 "MNDMST01", "", BS_NA, SC_NA, 0, 0x0b258977},
{"Escape MM Load 3",
 "MNDMST02", "", BS_NA, SC_NA, 0, 0x1e3ab551},
{"Escape MM Load 4",
 "MNDMST03", "", BS_NA, SC_NA, 0, 0x72de6bdb},
{"Espial (PAL)",
 "ESPIAL", "ESPIAL", BS_3F, SC_78BIOS, 1, 0x8d70fa42},
{"Euchre",
 "EUCHRE", "EUCHRE", BS_4K, SC_78BIOS, 1, 0x68bff6af},
{"Excalibur (Dragonstomper Proto)",
 "EXCALB00", "EXCALB00", BS_SC, SC_SC, 1, 0x0eb571ca},
{"Fantastic Voyage",
 "FNTSKVOY", "FNTSKVOY", BS_4K, SC_78BIOS, 1, 0x9e23d4b3},
{"Farmyard Fun (PAL)",
 "FARMYARD", "FARMYARD", BS_4K, SC_78BIOS, 1, 0x75e3ba5d},
{"Fast Eddie",
 "FASTED", "FASTED", BS_4K, SC_78BIOS, 1, 0x249f0b14},
{"Fast Food",
 "FASTFOOD", "FASTFOOD", BS_4K, SC_78BIOS, 1, 0xe2f2ce4e},
{"Fat Albert (Hack)",
 "FATALBRT", "FATALBRT", BS_4K, SC_78BIOS, 1, 0xbfe95959},
{"Fatal Run",
 "FATALRUN", "FATALRUN", BS_F4SC, SC_78BIOS, 1, 0x75220fe4},
{"Fathom",
 "FATHOM", "FATHOM", BS_F8, SC_78BIOS, 1, 0x05a357e7},
{"Fighter Pilot (PAL)",
 "FIGHTERP", "FIGHTERP", BS_F6, SC_78BIOS, 1, 0x389c4348},
{"Final Approach",
 "FINALAPR", "FINALAPR", BS_4K, SC_78BIOS, 1, 0xd3fcf9d9},
{"Fireball",
 "FIRBAL00", "FIRBAL00", BS_SC, SC_SC, 1, 0x19fc874c},
{"Fireball (demo)",
 "FIDEMO00", "FIDEMO00", BS_SC, SC_SC, 1, 0x670825d3},
{"Fire Fighter",
 "FIREFIGT", "FIREFIGT", BS_4K, SC_78BIOS, 1, 0x2b04383d},
{"Fire Fly",
 "FIREFLY", "FIREFLY", BS_4K, SC_78BIOS, 1, 0x1b7b182d},
{"Fire Spinner",
 "FIRESPIN", "FIRESPIN", BS_4K, SC_78BIOS, 1, 0xe8b1225f},
{"Fishing Derby",
 "FISHDERB", "FISHDERB", BS_2K, SC_78BIOS, 1, 0x18338c5f},
{"Flag Capture",
 "FLAGCAP", "FLAGCAP", BS_2K, SC_78BIOS, 1, 0x26d01010},
{"Flash Gordon",
 "FLASHGOR", "FLASHGOR", BS_4K, SC_78BIOS, 1, 0xda0de988},
{"Football",
 "FOOTBALL", "FOOTBALL", BS_2K, SC_78BIOS, 1, 0x46dfcdc1},
{"Forest (PAL)",
 "FOREST", "FOREST", BS_4K, SC_78BIOS, 1, 0x9d63d054},
{"Frankenstein's Monster",
 "FRANKMON", "FRANKMON", BS_4K, SC_78BIOS, 1, 0x04981c21},
{"Freeway",
 "FREEWAY", "FREEWAY", BS_2K, SC_78BIOS, 1, 0xe48fe1fc},
{"Frog Pond (Proto)",
 "FROGPOND", "FROGPOND", BS_F8, SC_78BIOS, 1, 0x4d8d5c0e},
{"Frogger (SC demo)",
 "FRDEMO00", "FRDEMO00", BS_SC, SC_SC, 1, 0xc25e2a52},
{"Frogger (Supercharger)",
 "FROGER00", "FROGER00", BS_SC, SC_SC, 1, 0xe28451f7},
{"Frogger",
 "FROGGER", "FROGGER", BS_4K, SC_78BIOS, 1, 0x71e94fe7},
{"Frogger II: Threeedeep",
 "FROGGER2", "FROGGER2", BS_E0, SC_78BIOS, 1, 0x2843d776},
{"Frogs and Flies",
 "FROGFLIS", "FROGFLIS", BS_4K, SC_78BIOS, 1, 0x9047b7f7},
{"Front Line",
 "FRNTLINE", "FRNTLINE", BS_F8, SC_78BIOS, 1, 0x611b352c},
{"Frostbite",
 "FROSTBTE", "FROSTBTE", BS_4K, SC_78BIOS, 1, 0x2f42999b},
{"Funky Fish",
 "FUNKFISH", "FUNKFISH", BS_UA, SC_78BIOS, 1, 0x2c19c728},
{"Galaxian",
 "GALAX", "GALAX", BS_F8, SC_78BIOS, 1, 0x45cafee1},
{"Galaxian Arcade (Jess Ragan)",
 "GALAX2", "GALAX2", BS_F8, SC_78BIOS, 1, 0x6ae81e10},
{"Gangster Alley",
 "GANGSTER", "GANGSTER", BS_4K, SC_78BIOS, 1, 0x70f1de80},
{"Garfield (Proto)",
 "GARFIELD", "GARFILED", BS_F6, SC_78BIOS, 1, 0xa099f3fd},
{"Gas Hog",
 "GASHOG", "GASHOG", BS_4K, SC_78BIOS, 1, 0x008103e0},
{"Gauntlet",
 "GAUNTLET", "GAUNTLET", BS_4K, SC_78BIOS, 1, 0xaef43487},
{"General Retreat (PAL)",
 "GENRLRET", "GENRLRET", BS_4K, SC_78BIOS, 1, 0x6b26e5ad},
{"Ghost Manor",
 "GHOSTMNR", "GHOSTMNR", BS_F8, SC_78BIOS, 1, 0x7df6c6cb},
{"Ghostbusters",
 "GHOST", "GHOST", BS_F8, SC_78BIOS, 1, 0xb4999aa3},
{"Ghostbusters II",
 "GHOST2", "GHOST2", BS_F6, SC_78BIOS, 1, 0x6570d0eb},
{"G.I. Joe: Cobra Strike",
 "GIJOE", "GIJOE", BS_4K, SC_78BIOS, 1, 0xb1ac01ae},
{"Glacier Patrol",
 "GLCRPTRL", "GLCRPTRL", BS_4K, SC_78BIOS, 1, 0xeea13ddc},
{"Glib",
 "GLIB", "GLIB", BS_4K, SC_78BIOS, 1, 0x328e1b51},
{"Golf",
 "GOLF", "GOLF", BS_2K, SC_78BIOS, 1, 0x1ef3a1c5},
{"Gopher",
 "GOPHER", "GOPHER", BS_4K, SC_78BIOS, 1, 0xd694cc9e},
{"Gorf",
 "GORF", "GORF", BS_4K, SC_78BIOS, 1, 0x2bc25098},
{"Gran Prix",
 "GRANPRIX", "GRANPRIX", BS_4K, SC_78BIOS, 1, 0x5a3b327d},
{"Gravitar",
 "GRAVITAR", "GRAVITAR", BS_F8, SC_78BIOS, 1, 0xc6dd25af},
{"Great Escape",
 "GREATESC", "GREATESC", BS_4K, SC_78BIOS, 1, 0x6f62a864},
{"Gremlins",
 "GREMLINS", "GREMLINS", BS_F8, SC_78BIOS, 1, 0xfd6b25e8},
{"Grover's Music Maker (Proto)",
 "GROVER", "GROVER", BS_F8, SC_78BIOS, 1, 0x97a27db8},
{"Guardian",
 "GUARDIAN", "GUARDIAN", BS_4K, SC_78BIOS, 1, 0x66202e85},
{"Gunfight",
 "GUNNTSC", "GUNFIGHT", BS_4K, SC_78BIOS, 1, 0x4530bbcd},
{"Gyruss",
 "GYRUSS", "GYRUSS", BS_E0, SC_78BIOS, 1, 0x525ee7e9},
{"H.E.R.O.",
 "HERO", "HERO", BS_F8, SC_78BIOS, 1, 0xc081def8},
{"Halloween",
 "HLLOWEEN", "HLLOWEEN", BS_4K, SC_78BIOS, 1, 0x37b55c29},
{"Hangman",
 "HANGMAN", "HANGMAN", BS_4K, SC_78BIOS, 1, 0x62253ca0},
{"Harbour Escape",
 "HARBRESC", "HARBRESC", BS_4K, SC_78BIOS, 1, 0x213ec4f5},
{"Haunted House",
 "HAUNTED", "HAUNTED", BS_4K, SC_78BIOS, 1, 0xfd624556},
{"Hell Driver",
 "HELLDRVR", "HELLDRVR", BS_4K, SC_78BIOS, 1, 0x8a52c48c},
{"High Bid (Ebay)",
 "HIGHBID", "HIGHBID", BS_4K, SC_78BIOS, 1, 0xf7f253c5},
{"Hole Hunter",
 "HOLEHNTR", "HOLEHNTR", BS_4K, SC_78BIOS, 1, 0xf50dd9f4},
{"Holy Moley (Proto)",
 "HOLYMOLY", "HOLYMOLY", BS_F8, SC_78BIOS, 1, 0xf777a07d},
{"Homerun",
 "HOMERUN", "HOMERUN", BS_2K, SC_78BIOS, 1, 0x06e5d652},
{"Hozer Video (Demo)",
 "HOZER", "HOZER", BS_4K, SC_78BIOS, 1, 0x7e9e3633},
{"HSPT (DEMO)",
 "HSPT", "HSPT", BS_4K, SC_78BIOS, 1, 0x8ec91c5b},
{"Human Cannonball",
 "HUMANCAN", "HUMANCAN", BS_2K, SC_78BIOS, 1, 0x8e17b4b8},
{"I Want My Mommy",
 "IWANTMOM", "IWANTMOM", BS_4K, SC_78BIOS, 1, 0xc4be9818},
{"Ice Hockey",
 "ICEHOCKY", "ICEHOCKY", BS_4K, SC_78BIOS, 1, 0x9c535bbd},
{"Ikari Warriors",
 "IKARI", "IKARI", BS_F6, SC_78BIOS, 1, 0xb554d5b3},
{"Imagic Cart Selector",
 "IMAGIC", "IMAGIC", BS_4K, SC_78BIOS, 1, 0xecea9c12},
{"Immies & Aggies",
 "IMMIES", "IMMIES", BS_4K, SC_78BIOS, 1, 0x2bcce2c8},
{"Indy 500",
 "INDY500", "INDY500", BS_2K, SC_78BIOS, 1, 0xf6347068},
{"Infiltrate",
 "INFLTRTE", "INFLTRTE", BS_4K, SC_78BIOS, 1, 0xc39c7a29},
{"International Soccer",
 "INTLSOCR", "INTLSOCR", BS_4K, SC_78BIOS, 1, 0x0140a2ff},
{"INV",
 "INV", "INV", BS_4K, SC_78BIOS, 1, 0xa9547f24},
{"IQ 180",
 "IQ180", "IQ180", BS_4K, SC_78BIOS, 1, 0xb8f2d930},
{"James Bond 007",
 "JAMSBOND", "JAMSBOND", BS_E0, SC_78BIOS, 1, 0x3216c1bb},
{"Jammed",
 "JAMMED", "JAMMED", BS_4K, SC_78BIOS, 1, 0x80884b08},
{"Jawbreaker",
 "JAWBRKR", "JAWBRKR", BS_4K, SC_78BIOS, 1, 0xefb60ada},
{"Journey Escape",
 "JRNYESC", "JRNYESC", BS_4K, SC_78BIOS, 1, 0x3d77201b},
{"Joust",
 "JOUST", "JOUST", BS_F8, SC_78BIOS, 1, 0xde6d008e},
{"Jr. Pac-Man",
 "JRPACMAN", "JRPACMAN", BS_F6SC, SC_78BIOS, 1, 0xb43c3e99},
{"Junglehunt",
 "JNGLHUNT", "JNGLHUNT", BS_F8, SC_78BIOS, 1, 0xc3b54f5e},
{"Kabobber (Proto)",
 "KABOBER", "KABOBER", BS_4K, SC_78BIOS, 1, 0xba191b46},
{"Kaboom",
 "KABOOM", "KABOOM", BS_2K, SC_78BIOS, 1, 0xf2d1b43c},
{"Kamikazi Saucer",
 "KAMIKAZ", "KAMIKAZ", BS_4K, SC_78BIOS, 1, 0xfd7644bd},
{"Kangaroo",
 "KANGEROO", "KANGEROO", BS_F8, SC_78BIOS, 1, 0x6a20dafe},
{"Karate",
 "KARATE", "KARATE", BS_4K, SC_78BIOS, 1, 0xf7a07e8d},
{"Keystone Kapers",
 "KEYSTONE", "KEYSTONE", BS_4K, SC_78BIOS, 1, 0x321f31c5},
{"Killer Satellites",
 "KILLER00", "KILLER00", BS_SC, SC_SC, 1, 0xc2898b39},
{"Killer Satellites (Demo)",
 "KSDEMO00", "KSDEMO00", BS_SC, SC_SC, 1, 0x38568b0e},
{"King Kong",
 "KINGKONG", "KINGKONG", BS_4K, SC_78BIOS, 1, 0x84a23e70},
{"KLAX",
 "KLAX", "KLAX", BS_F6SC, SC_78BIOS, 1, 0xfad6471a},
{"Knight on the Town",
 "KNIGHT", "KNIGHT", BS_4K, SC_78BIOS, 1, 0x714a692b},
{"Kool-Aid Man",
 "KOOLAID", "KOOLAID", BS_4K, SC_78BIOS, 1, 0x6f721775},
{"Krull",
 "KRULL", "KRULL", BS_F8, SC_78BIOS, 1, 0xdcc86139},
{"Kung-Fu Master",
 "KUNGFU", "KUNGFU", BS_F8, SC_78BIOS, 1, 0x69f0e581},
{"Laser Blast",
 "LASRBLST", "LASRBLST", BS_2K, SC_78BIOS, 1, 0xcb98b732},
{"Laser Gates",
 "LASRGATE", "LASRGATE", BS_4K, SC_78BIOS, 1, 0x1a8c369a},
{"Last Starfighter, The (Proto)",
 "LASTSTAR", "LASTSTAR", BS_F6, SC_F6BANK0, 1, 0x511713c4},
{"Lilly Adventure",
 "LILLYADV", "LILLYADV", BS_4K, SC_78BIOS, 1, 0xf0c143f3},
{"Lock 'n Chase",
 "LOCKNCHS", "LOCKNCHS", BS_4K, SC_78BIOS, 1, 0x0f952c65},
{"London Blitz",
 "LONBLITZ", "LONBLITZ", BS_4K, SC_78BIOS, 1, 0x42430a06},
{"Looping (Proto)",
 "LOOPING", "LOOPING", BS_F8, SC_F8BANK1, 1, 0x476646ba},
{"Lord of the Rings (Proto)",
 "LORDRING", "LORDRING", BS_E0, SC_78BIOS, 1, 0x6400d110},
{"Lord of the Rings (Fellowship)",
 "LORDFELL", "LORDFELL", BS_4K, SC_78BIOS, 1, 0x49176010},
{"Lost Luggage",
 "LOSTLUGG", "LOSTLUGG", BS_4K, SC_78BIOS, 1, 0x99996199},
{"M*A*S*H",
 "MASH", "MASH", BS_4K, SC_78BIOS, 1, 0x816548af},
{"M.A.D",
 "MAD", "MAD", BS_4K, SC_78BIOS, 1, 0x759d5526},
{"MagiCard",
 "MAGICARD", "MAGICARD", BS_CV, SC_78BIOS, 1, 0x34ae2945},
{"Malagai",
 "MALAGAI", "MALAGAI", BS_4K, SC_78BIOS, 1, 0x67b79cd2},
{"Mangia",
 "MANGIA", "MANGIA", BS_4K, SC_78BIOS, 1, 0x490cb3d1},
{"Marauder",
 "MARAUDER", "MARAUDER", BS_4K, SC_78BIOS, 1, 0x0ede1179},
{"Marble Craze",
 "MARBLE", "MARBLE", BS_F4, SC_78BIOS, 1, 0x095a655f},
{"Marine Wars",
 "MARINE", "MARINE", BS_4K, SC_78BIOS, 1, 0x2083ea34},
{"Mario Bros.",
 "MARIO", "MARIO", BS_F8, SC_78BIOS, 1, 0xdffd2832},
{"Mario Bros. Arcade",
 "MARIO2", "MARIO2", BS_F8, SC_78BIOS, 1, 0x95a7aa24},
{"Mark's Sound Demo",
 "MARKSND", "MARKSND", BS_4K, SC_78BIOS, 1, 0x99421574},
{"Master Builder",
 "MASTRBLD", "MASTRBLD", BS_4K, SC_78BIOS, 1, 0xfeae6860},
{"Masters of the Universe",
 "MASTER", "MASTER", BS_E7, SC_78BIOS, 1, 0x5c161fe4},
{"Math Gran Prix",
 "MATHPRIX", "MATHPRIX", BS_4K, SC_78BIOS, 1, 0xd2a2aee7},
{"Maze Craze",
 "MAZECRZE", "MAZECRZE", BS_4K, SC_78BIOS, 1, 0x28b02d7f},
{"McDonald's (proto)",
 "MCDONALD", "MCDONALD", BS_4K, SC_78BIOS, 1, 0x98453027},
{"Mega Boy",
 "MEGABOY", "MEGABOY", BS_MEGABOY, SC_78BIOS, 1, 0x8de3c9b0},
{"Mega Force",
 "MEGAFORC", "MEGAFORC", BS_4K, SC_78BIOS, 1, 0x7be1f9ea},
{"Megamania",
 "MEGAMAN", "MEGAMAN", BS_4K, SC_78BIOS, 1, 0x83428934},
{"Merlin's Walls",
 "MERLIN", "MERLIN", BS_4K, SC_78BIOS, 1, 0x74cbcee6},
{"Meteoroids ( Proto)",
 "METERD00", "METERD00", BS_SC, SC_SC, 1, 0x51d72cee},
{"Midnight Magic",
 "MIDNITE", "MIDNITE", BS_F6, SC_78BIOS, 1, 0x286422ce},
{"Millipede",
 "MILLIPDE", "MILLIPDE", BS_F6SC, SC_78BIOS, 1, 0xcc902aa0},
{"Millipede (Proto)",
 "MILPROTO", "MILPROTO", BS_F6SC, SC_78BIOS, 1, 0xd761e6c2},
{"Mind Maze (proto)",
 "MINDMAZE", "MINDMAZE", BS_F8, SC_78BIOS, 1, 0x9cec02ab},
{"Miner 2049'er",
 "MINER", "MINER", BS_3F, SC_78BIOS, 1, 0x728b941c},
{"Miner 2049'er Volume 2",
 "MINER2", "MINER2", BS_3F, SC_78BIOS, 1, 0x350c63ba},
{"Mines of Minos",
 "MINESMIN", "MINESMIN", BS_4K, SC_78BIOS, 1, 0x421d090e},
{"Miniature Golf",
 "MINGOLF", "MINGOLF", BS_2K, SC_78BIOS, 1, 0x0dba427c},
{"Miniature Golf Plus",
 "MINGOLF2", "MINGOLF2", BS_4K, SC_78BIOS, 1, 0xf56b90e2},
{"Miss Piggy's Wedding (Proto)",
 "MISSPIG", "MISSPIG", BS_F8, SC_78BIOS, 1, 0x5e4d44d1},
{"Missile Command",
 "MISLCMD", "MISLCMD", BS_4K, SC_78BIOS, 1, 0xf48b6b4c},
{"Missile Control",
 "MSCNTRL", "MSCNTRL", BS_4K, SC_78BIOS, 1, 0xd9a600b2},
{"Mission 3000 AD (PAL)",
 "MIS3000", "MIS3000", BS_4K, SC_78BIOS, 1, 0x80f5e00e},
{"Mission Survive",
 "MISURVIV", "MISURVIV", BS_4K, SC_78BIOS, 1, 0x7babc61b},
{"Mogul Maniac",
 "MOGULMAN", "MOGULMAN", BS_4K, SC_78BIOS, 1, 0xa2443eb1},
{"Mondo Pong",
 "MONDOPNG", "MONDOPNG", BS_4K, SC_78BIOS, 1, 0x451f45dd},
{"Monstercise (Proto)",
 "MNSTRCSE", "MNSTRCSE", BS_F8, SC_78BIOS, 1, 0x35ace809},
{"Montezuma's Revenge",
 "MONTEZUM", "MONTEZUM", BS_E0, SC_78BIOS, 1, 0xae4114d8},
{"Moon Patrol",
 "MOONPAT", "MOONPAT", BS_F8, SC_78BIOS, 1, 0xaddeb4db},
{"Moonsweeper",
 "MOONSWPR", "MOONSWPR", BS_F8, SC_F8BANK1, 1, 0xd865a8dd},
{"Motocross (PAL)",
 "MOTOCRSS", "MOTOCRSS", BS_4K, SC_78BIOS, 1, 0x25967483},
{"Motocross Racer",
 "MOTORACR", "MOTORACR", BS_F8, SC_78BIOS, 1, 0x32a4a113},
{"Motorodeo (PAL)",
 "MOTORODE", "MOTORODE", BS_F6, SC_78BIOS, 1, 0x393372e5},
{"Mountain King",
 "MTNKING", "MTNKING", BS_FA, SC_78BIOS, 1, 0x80f09601},
{"Mountain Man",
 "MTNMAN", "MTNMAN", BS_4K, SC_78BIOS, 1, 0x1ee2ddf3},
{"Mouse Trap",
 "MOUSETR", "MOUSTR", BS_4K, SC_78BIOS, 1, 0x405464ee},
{"Mr. Do!",
 "MRDO", "MRDO", BS_F8, SC_78BIOS, 1, 0x596160d3},
{"Mr. Do's Castle",
 "MRDOCAS", "MRDOCAS", BS_E0, SC_78BIOS, 1, 0x00e44527},
{"Mr. Postman (PAL)",
 "MRPOST", "MRPOST", BS_4K, SC_78BIOS, 1, 0x9503eb91},
{"Mr. Roboto (hack)",
 "MRROBOTO", "MRROBOTO", BS_F8, SC_78BIOS, 1, 0x5a21e1cb},
{"Ms. Pac-Man",
 "MSPACMAN", "MSPACMAN", BS_F8, SC_78BIOS, 1, 0xeffd25db},
{"Music Machine",
 "MUSICMAC", "MUSICMAC", BS_4K, SC_78BIOS, 1, 0xa550e765},
{"My Golf",
 "MYGOLF", "MYGOLF", BS_F8, SC_78BIOS, 1, 0xc7eccf7c},
{"Name This Game",
 "NAME", "NAME", BS_4K, SC_78BIOS, 1, 0xba351bd6},
{"Night Driver",
 "NITEDRVR", "NITEDRVR", BS_2K, SC_78BIOS, 1, 0xf2ab3c3b},
{"Night Stalker",
 "NITESTLK", "NITESTLK", BS_4K, SC_78BIOS, 1, 0x00e5f221},
{"No Escape!",
 "NOESC", "NOESC", BS_4K, SC_78BIOS, 1, 0xcddb038a},
{"Nuts",
 "NUTS", "NUTS", BS_4K, SC_78BIOS, 1, 0x5dd6a386},
{"NWCGE Invaders (ResQsoft)",
 "NWCGE", "NWCGE", BS_4K, SC_78BIOS, 1, 0xc170f6b7},
{"Obelix",
 "OBELIX", "OBELIX", BS_F8, SC_78BIOS, 1, 0xda20ed6c},
{"Octopus",
 "OCTOPUS", "OCTOPUS", BS_4K, SC_78BIOS, 1, 0xcd3ebae1},
{"Off the Wall",
 "OFFWALL", "OFFWALL", BS_F6SC, SC_78BIOS, 1, 0x66cdb94b},
{"Off your Rocker (Proto)",
 "OFFROCK", "OFFROCK", BS_4K, SC_78BIOS, 1, 0xc62b9894},
{"Oink!",
 "OINK", "OINK", BS_4K, SC_78BIOS, 1, 0xfa731279},
{"Okie Dokie",
 "OKIEDOKI", "OKIEDOKI", BS_2K, SC_78BIOS, 1, 0xc79b8bc1},
{"Omega Race",
 "OMEGA", "OMEGA", BS_FA, SC_78BIOS, 1, 0x9fa932c2},
{"Omega Race (DC Hack)",
 "OMEGADC", "OMEGADC", BS_FA, SC_78BIOS, 1, 0x9ed32a80},
{"Open Sesame",
 "SESAME", "SESAME", BS_4K, SC_78BIOS, 1, 0x416484c3},
{"Oscar's Trash Race (PAL)",
 "OSCAR", "OSCAR", BS_F8, SC_78BIOS, 1, 0xf1a47d0e},
{"Othello",
 "OTHELLO", "OTHELLO", BS_2K, SC_78BIOS, 1, 0xae6e0835},
{"Out of Control",
 "OUTCNTRL", "OUTCNTRL", BS_4K, SC_78BIOS, 1, 0xc132fb87},
{"Outlaw",
 "OUTLAW", "OUTLAW", BS_2K, SC_78BIOS, 1, 0x725c658f},
{"Oystron",
 "OYSTRON", "OYSTRON", BS_4K, SC_78BIOS, 1, 0x16802560},
{"Oystronx",
 "OYSTRONX", "OYSTRONX", BS_4K, SC_78BIOS, 1, 0x57da85f1},
{"Pac-Kong",
 "PACKONG", "PACKONG", BS_4K, SC_78BIOS, 1, 0xe0ec567a},
{"Pac-Man",
 "PACMAN", "PACMAN", BS_4K, SC_78BIOS, 1, 0x16d29a52},
{"Pac-Man Arcade",
 "PACARCAD", "PACARCAD", BS_F8, SC_78BIOS, 1, 0xe477747d},
{"Pac-Man (Ebivision)",
 "PACMANEB", "PACMANEB", BS_4K, SC_78BIOS, 1, 0xd17f2693},
{"Panda Chase",
 "PANDACHS", "PANDACHS", BS_4K, SC_78BIOS, 1, 0xf3ded2e3},
{"Parachute",
 "PARACHUT", "PARACHUT", BS_4K, SC_78BIOS, 1, 0xfa59d580},
{"Party Mix Demo",
 "PMDEMO00", "PMDEMO00", BS_SC, SC_SC, 1, 0xc0d6f4e8},
{"Party Mix Load 1",
 "PYMIX100", "PYMIX100", BS_SC, SC_SC, 1, 0xf4b12a3e},
{"Party Mix Load 2",
 "PYMIX200", "PYMIX200", BS_SC, SC_SC, 1, 0x1bdbeff7},
{"Party Mix Load 3",
 "PYMIX300", "PYMIX300", BS_SC, SC_SC, 1, 0x5ef85036},
{"Peek-A-Boo (Proto)",
 "PEEKBOO", "PEEKBOO", BS_4K, SC_78BIOS, 1, 0xc3e91b95},
{"Pele's Soccer",
 "PELESOCR", "PELESOCR", BS_4K, SC_78BIOS, 1, 0x8a7089f0},
{"Pengo",
 "PENGO", "PENGO", BS_F8, SC_78BIOS, 1, 0xeda8d4f8},
{"Pesco",
 "PESCO", "PESCO", BS_4K, SC_78BIOS, 1, 0xa0313f39},
{"Pete Rose Baseball",
 "PETEROSE", "PETEROSE", BS_F6, SC_78BIOS, 1, 0x67463bcd},
{"Pharoah's Curse",
 "PHAROAH", "PHAROAH", BS_4K, SC_78BIOS, 1, 0xb087d2b6},
{"Phasor Patrol",
 "PHASOR00", "PHASOR00", BS_SC, SC_SC, 1, 0x86bc321d},
{"Phoenix",
 "PHEONIX", "PHEONIX", BS_F8, SC_78BIOS, 1, 0xfc7f3de9},
{"Pick 'N' Pile (PAL)",
 "PICKPILE", "PICKPILE", BS_F6, SC_78BIOS, 1, 0x7b4eb49c},
{"Pick Up (proto)",
 "PICKUP", "PICKUP", BS_4K, SC_78BIOS, 1, 0xdea27aeb},
{"Picnic",
 "PICNIC", "PICNIC", BS_4K, SC_78BIOS, 1, 0x17e3509b},
{"Piece 'o Cake",
 "PIECECAK", "PIECECAK", BS_4K, SC_78BIOS, 1, 0x1eddbbff},
{"Pigs in Space",
 "PIGSPACE", "PIGSPACE", BS_F8, SC_78BIOS, 1, 0x93c15c0f},
{"Pitfall",
 "PITFALL", "PITFALL", BS_4K, SC_78BIOS, 1, 0xcb12b389},
{"Pizza Chef",
 "PIZACHEF", "PIZACHEF", BS_4K, SC_78BIOS, 1, 0x9c0bf027},
{"Planet of the Apes (proto)",
 "PLANAPES", "PLANAPES", BS_4K, SC_78BIOS, 1, 0xcdd716c9},
{"Planet Patrol",
 "PLNTPAT", "PLNTPAT", BS_4K, SC_78BIOS, 1, 0x574786fe},
{"Plaque Attack",
 "PLAQUE", "PLAQUE", BS_4K, SC_78BIOS, 1, 0x14890876},
{"Pleiades",
 "PLEIADES", "PLEIADES", BS_UA, SC_78BIOS, 1, 0xbc5527e7},
{"Polaris",
 "POLARIS", "POLARIS", BS_3F, SC_78BIOS, 1, 0x3310b79e},
{"Pole Position",
 "POLEPSTN", "POLEPSTN", BS_F8, SC_78BIOS, 1, 0x162a4296},
{"Polo (Proto)",
 "POLO", "POLO", BS_2K, SC_78BIOS, 1, 0xa69d4b5f},
{"Polo Special Edition",
 "POLO2", "POLO2", BS_F8, SC_78BIOS, 1, 0x33752239},
{"Pompeii (Proto)",
 "POMPEII", "POMPEII", BS_4K, SC_78BIOS, 1, 0x1852cd14},
{"Pooyan",
 "POOYAN", "POOYAN", BS_4K, SC_78BIOS, 1, 0x5f2f97cb},
{"Popeye",
 "POPEYE", "POPEYE", BS_E0, SC_78BIOS, 1, 0xf723b8a6},
{"Porky's",
 "PORKYS", "PORKYS", BS_F8, SC_78BIOS, 1, 0xb79d36f8},
{"Power Off",
 "POWEROFF", "POWEROFF", BS_4K, SC_78BIOS, 1, 0x013c6493},
{"Pressure Cooker",
 "PRESSCKR", "PRESSCKR", BS_F8, SC_78BIOS, 1, 0x36feebfc},
{"Pressure Gauge (John Harvey)",
 "PRESGAUG", "PRESGAUG", BS_4K, SC_78BIOS, 1, 0x0a0c9d67},
{"Private Eye",
 "PRVTEYE", "PRVTEYE", BS_F8, SC_78BIOS, 1, 0x33242242},
{"Q*Bert",
 "QBERT", "QBERT", BS_4K, SC_78BIOS, 1, 0x709f787f},
{"Q*Bert's Qubes",
 "QBERTQUB", "QBERTQUB", BS_E0, SC_78BIOS, 1, 0xe44c244e},
{"QB",
 "QB", "QB", BS_4K, SC_78BIOS, 1, 0x23184b03},
{"Quadrun",
 "QUADRUN", "QUADRUN", BS_F8, SC_78BIOS, 1, 0xbf31abf0},
{"Quest for Quinta Roo",
 "QUESTROO", "QUESTROO", BS_F8, SC_78BIOS, 1, 0xc49fc0fe},
{"Quick Step",
 "QUIKSTEP", "QUIKSTEP", BS_4K, SC_78BIOS, 1, 0x48dc5381},
{"Rabbit Transit (Atari Proto)",
 "RABBIT", "RABBIT", BS_F8, SC_78BIOS, 1, 0xa9dc9de0},
{"Rabbit Transit (Demo)",
 "RTDEMO00", "RTDEMO00", BS_SC, SC_SC, 1, 0x18c6f37c},
{"Rabbit Transit",
 "RABBIT00", "RABBIT00", BS_SC, SC_SC, 1, 0x4673b2a8},
{"Racquetball",
 "RQTBALL", "RQTBALL", BS_4K, SC_78BIOS, 1, 0x85bc70de},
{"Radar Lock",
 "RADARLOK", "RADARLOK", BS_F6SC, SC_78BIOS, 1, 0xbaa38059},
{"Raft Rider",
 "RAFTRIDR", "RAFTRIDR", BS_4K, SC_78BIOS, 1, 0x972e8557},
{"Raiders of the Lost Ark",
 "RAIDERS", "RAIDERS", BS_F8, SC_78BIOS, 1, 0x0eb247a3},
{"Ram It",
 "RAMIT", "RAMIT", BS_4K, SC_78BIOS, 1, 0xfea4e837},
{"Rampage",
 "RAMPAGE", "RAMPAGE", BS_F6, SC_78BIOS, 1, 0xf52822a2},
{"Reactor",
 "REACTOR", "REACTOR", BS_4K, SC_78BIOS, 1, 0x60ca5d54},
{"Realsports Baseball",
 "RSBSBALL", "RSBSBALL", BS_F8, SC_78BIOS, 1, 0x55da122d},
{"Realsports Basketball (Proto)",
 "RSBSKBAL", "RSBSKBAL", BS_F8, SC_78BIOS, 1, 0x9e1b5fb0},
{"Realsports Boxing",
 "RSBOXING", "RSBOXING", BS_F6, SC_78BIOS, 1, 0x19d692a0},
{"Realsports Football",
 "RSFTBALL", "RSFTBALL", BS_F8, SC_78BIOS, 1, 0x5b171752},
{"Realsports Soccer",
 "RSSCCOR", "RSSCCOR", BS_F8, SC_78BIOS, 1, 0x1b377280},
{"Realsports Tennis",
 "RSTENNIS", "RSTENNIS", BS_F8, SC_78BIOS, 1, 0x50183e88},
{"Realsports Volleyball",
 "RSVLYBAL", "RSVLYBAL", BS_4K, SC_78BIOS, 1, 0xefd799b2},
{"Rescue Bira Bira",
 "RESQBIRA", "RESQBIRA", BS_4K, SC_78BIOS, 1, 0xf78c1ef6},
{"Rescue Terra I",
 "RESQTERA", "RESQTERA", BS_4K, SC_78BIOS, 1, 0x8d6b17b3},
{"Revenge of the Apes",
 "REVAPES", "REVAPES", BS_F8, SC_78BIOS, 1, 0xd74fbbbf},
{"Revenge of the BS Tomatoes",
 "REVENGE", "REVENGE", BS_4K, SC_78BIOS, 1, 0x744c2941},
{"Riddle of the Sphinx",
 "RIDSPHNX", "RIDSPHNX", BS_4K, SC_78BIOS, 1, 0xb2dc8f20},
{"River Patrol",
 "RIVERPAT", "RIVERPAT", BS_3F, SC_78BIOS, 1, 0x40706361},
{"River Raid",
 "RIVERAID", "RIVERAID", BS_4K, SC_78BIOS, 1, 0x256de643},
{"River Raid ][",
 "RIVERAD2", "RIVERAD2", BS_F6, SC_78BIOS, 1, 0x0341cc73},
{"Road Runner",
 "RDRUNNER", "RDRUNNER", BS_F6, SC_78BIOS, 1, 0x3305e868},
{"Road Runner",
 "RDRUNNER", "RDRUNNER", BS_F6, SC_F6BANK0, 1, 0x56ac2499},
{"Robin Hood",
 "ROBINHD", "ROBINHD", BS_F8, SC_78BIOS, 1, 0xb8389dc1},
{"Robot Fight  (PAL)",
 "ROBOTFT", "ROBOTFT", BS_4K, SC_78BIOS, 1, 0x2aace942},
{"Robot Tank",
 "ROBOTANK", "ROBOTANK", BS_FE, SC_78BIOS, 1, 0xa51c0236},
{"Roc 'N Rope",
 "ROCROPE", "ROCROPE", BS_F8, SC_78BIOS, 1, 0x103dd194},
{"Rocky and Bullwinkle",
 "ROCKYBUL", "ROCKYBUL", BS_4K, SC_78BIOS, 1, 0x64b43824},
{"Room of Doom",
 "ROOMDOOM", "ROOMDOOM", BS_4K, SC_78BIOS, 1, 0x62171047},
{"Rush Hour",
 "RUSHHR", "RUSHHR", BS_4K, SC_78BIOS, 1, 0x938b88a2},
{"Saboteur (Proto)",
 "SABOTUER", "SABOTUER", BS_F8, SC_78BIOS, 1, 0x6970b9bd},
{"Save Mary!",
 "SAVEMARY", "SAVEMARY", BS_F6SC, SC_78BIOS, 1, 0x1429356e},
{"Save The Whales",
 "SAVE", "SAVE", BS_4K, SC_78BIOS, 1, 0xfa786dc1},
{"Save Our Ship  (PAL)",
 "SOS", "SOS", BS_4K, SC_78BIOS, 1, 0x680a43b0},
{"Say (Talking Stella)",
 "SAY", "SAY", BS_4K, SC_78BIOS, 1, 0x30ab9fd3},
{"Scsicide",
 "SCSICIDE", "SCSICIDE", BS_4K, SC_78BIOS, 1, 0x04839db5},
{"Scuba Diver",
 "SCUBA", "SCUBA", BS_4K, SC_78BIOS, 1, 0x45e79e48},
{"Sea Battle",
 "SBATTLE", "SBATTLE", BS_4K, SC_78BIOS, 1, 0xd64dc145},
{"Sea Hawk",
 "SEAHAWK", "SEAHAWK", BS_4K, SC_78BIOS, 1, 0x2ee9efd3},
{"Sea Monster  (PAL)",
 "SEAMON", "SEAMON", BS_4K, SC_78BIOS, 1, 0x88c2cbbc},
{"Seaquest",
 "SEAQUEST", "SEAQUEST", BS_4K, SC_78BIOS, 1, 0xbe0ac5cb},
{"Secret Agent (Proto)",
 "SECRETAG", "SECRETAG", BS_4K, SC_78BIOS, 1, 0x22965081},
{"Secret Quest",
 "SECQUEST", "SECQUEST", BS_F6SC, SC_78BIOS, 1, 0x0a3c8d46},
{"Sentinel",
 "SENTINEL", "SENTINEL", BS_F6, SC_78BIOS, 1, 0x56e2d735},
{"Shark Attack",
 "SHARKATK", "SHARKATK", BS_4K, SC_78BIOS, 1, 0x4c4229ce},
{"Ship Demo",
 "SHIPDEMO", "SHIPDEMO", BS_4K, SC_78BIOS, 1, 0x43963ade},
{"Shootin' Gallery",
 "SHOOTGAL", "SHOOTGAL", BS_4K, SC_78BIOS, 1, 0x415f5c53},
{"Shooting Arcade (Proto)",
 "SHOOTARC", "SHOOTARC", BS_F6SC, SC_78BIOS, 1, 0x0febd060},
{"Shuttle Orbiter",
 "SHUTTLE", "SHUTTLE", BS_4K, SC_78BIOS, 1, 0x69e14fde},
{"Sinistar (Proto)",
 "SINISTAR", "SINISTAR", BS_F8, SC_78BIOS, 1, 0xac5ea499},
{"Sir Lancelot",
 "SIRLANCE", "SIRLANCE", BS_F8, SC_78BIOS, 1, 0x27eda935},
{"Skateboardin'",
 "SKATBORD", "SKATBORD", BS_F8, SC_78BIOS, 1, 0xb6f8f9fe},
{"Skeet Shoot",
 "SKEETSHT", "SKEETSHT", BS_2K, SC_78BIOS, 1, 0xaf846e3e},
{"Ski Hunt (PAL)",
 "SKIHUNT", "SKIHUNT", BS_4K, SC_78BIOS, 1, 0xfae4f9fa},
{"Ski Run (PAL)",
 "SKIRUN", "SKIRUN", BS_4K, SC_78BIOS, 1, 0xde274ab1},
{"Skiing",
 "SKIING", "SKIING", BS_2K, SC_78BIOS, 1, 0xc7bf7b53},
{"Sky Diver",
 "SKYDIVER", "SKYDIVER", BS_2K, SC_78BIOS, 1, 0x2f33e90b},
{"Sky Jinks",
 "SKYJINKS", "SKYJINKS", BS_2K, SC_78BIOS, 1, 0x5d86d166},
{"Sky Patrol (Proto)",
 "SKYPATRL", "SKYPATRL", BS_F8, SC_78BIOS, 1, 0xaa90bdb2},
{"Sky Skipper",
 "SKYSKIP", "SKYSKIP", BS_4K, SC_78BIOS, 1, 0x9f58c4c9},
{"Slot Machine",
 "SLOTMACH", "SLOTMACH", BS_2K, SC_78BIOS, 1, 0x71810e32},
{"Slot Racers",
 "SLOTRACR", "SLOTRACR", BS_2K, SC_78BIOS, 1, 0xfd1925ed},
{"Smurf: RIGC",
 "SMURF", "SMURF", BS_F8, SC_78BIOS, 1, 0x4441a883},
{"Smurfs Save the Day",
 "SMURF2", "SMURF2", BS_F8, SC_78BIOS, 1, 0x9927a7ae},
{"Snail Against Squirrel",
 "SNAIL", "SNAIL", BS_4K, SC_78BIOS, 1, 0xb7bfd4f5},
{"Sneak 'n Peek",
 "SNKPEEK", "SNKPEEK", BS_4K, SC_78BIOS, 1, 0x7f718ba4},
{"Snoopy and the Red Barron",
 "SNOOPY", "SNOOPY", BS_F8, SC_78BIOS, 1, 0xc1adf48b},
{"Solar Fox",
 "SOLARFOX", "SOLARFOX", BS_F8, SC_78BIOS, 1, 0xe26ca84f},
{"Solar Storm",
 "SOLARSTM", "SOLARSTM", BS_4K, SC_78BIOS, 1, 0x922a0836},
{"Solaris",
 "SOLARIS", "SOLARIS", BS_F6, SC_78BIOS, 1, 0xab008372},
{"SoundX",
 "SOUNDX", "SOUNDX", BS_4K, SC_78BIOS, 1, 0x708d91c2},
{"Sourcerer",
 "SOCERER", "SOCERER", BS_4K, SC_78BIOS, 1, 0xe7a45722},
{"Sourcerer's Apprentice",
 "SOCCAPP", "SOCCAPP", BS_F8, SC_78BIOS, 1, 0xf04101f8},
{"Space Attack",
 "SPACEATK", "SPACEATK", BS_4K, SC_78BIOS, 1, 0x769601a0},
{"Space Canyon (PAL)",
 "SPCAECAN", "SPACECAN", BS_4K, SC_78BIOS, 1, 0x6da2cd05},
{"Space Cavern",
 "SPACECAV", "SPCAECAV", BS_4K, SC_78BIOS, 1, 0x88f336d3},
{"Space Instigators (Chris Tumber)",
 "SPACEINT", "SPACEINT", BS_F8, SC_78BIOS, 1, 0x13e9ef88},
{"Space Invaders",
 "SPACEINV", "SPACEINV", BS_4K, SC_78BIOS, 1, 0x4d5cfcf3},
{"Space Invaders Hack",
 "SPACEHAK", "SPACEHAK", BS_4K, SC_78BIOS, 1, 0xa99d77fa},
{"Space Invaders (Jeff Mintner)",
 "SPCJEFF", "SPCJEFF", BS_4K, SC_78BIOS, 1, 0x3f701a8d},
{"Space Invaders  (Arcade)",
 "SPCARCDE", "SPCARDE", BS_4K, SC_78BIOS, 1, 0xb4846515},
{"Space Jockey",
 "SPCJOCK", "SPCJOCK", BS_2K, SC_78BIOS, 1, 0xe50919d8},
{"Space Raid (hack)",
 "SPCRAID", "SPCRAID", BS_4K, SC_78BIOS, 1, 0x77ed2766},
{"Space Robot",
 "SPCROBOT", "SPCROBOT", BS_4K, SC_78BIOS, 1, 0x231e70a6},
{"Space Shuttle",
 "SPCSHUTT", "SPCSHUTT", BS_F8, SC_78BIOS, 1, 0xa053ba47},
{"Space Treat",
 "SPCTREAT", "SPCTREAT", BS_4K, SC_78BIOS, 1, 0x65b9fc95},
{"Space Treat Deluxe",
 "SPCTRTD", "SPCTRTD", BS_4K, SC_78BIOS, 1, 0xa4705ca4},
{"Space Treat Deluxe (PAL)",
 "SPCTRTDP", "SPCTRTDP", BS_4K, SC_78BIOS, 1, 0xf0d5f8a9},
{"Space Tunnel",
 "SPCTUNL", "SPCTUNL", BS_4K, SC_78BIOS, 1, 0xa9d7698f},
{"Space War",
 "SPCWAR", "SPCWAR", BS_2K, SC_78BIOS, 1, 0x427decb1},
{"Spacechase",
 "SPCCHSE", "SPCCHSE", BS_4K, SC_78BIOS, 1, 0x67e8747d},
{"Spacemaster X-7",
 "SPCMAS", "SPMAS", BS_4K, SC_78BIOS, 1, 0x079283cd},
{"Spider Fighter",
 "SPIDFITR", "SPIDFTR", BS_4K, SC_78BIOS, 1, 0x16bb74ce},
{"Spider-Man",
 "SPIDMAN", "SPIDMAN", BS_4K, SC_78BIOS, 1, 0x14c39b5e},
{"Spike's Peak",
 "SPIKEPK", "SPIKEPK", BS_F8, SC_78BIOS, 1, 0x23df6cd7},
{"Spitfire Attack",
 "SPITFIRE", "SPITFIRE", BS_4K, SC_78BIOS, 1, 0xb939dac4},
{"Springer",
 "SPRINGER", "SPRINGER", BS_3F, SC_78BIOS, 1, 0x2c34898f},
{"Sprintmaster",
 "SPRTMSTR", "SPRTMSTR", BS_F6SC, SC_78BIOS, 1, 0xff85cf1e},
{"Sprintmaster DC",
 "SPRTMSDC", "SPRTMSDC", BS_F6SC, SC_78BIOS, 1, 0x5b9f7df7},
{"Spy Hunter",
 "SPYHNTR", "SPYHNTR", BS_F8, SC_78BIOS, 1, 0x4e7e243d},
{"Squeeze Box",
 "SQZBOX", "SQZBOX", BS_4K, SC_78BIOS, 1, 0xaf362013},
{"Squoosh (Proto)",
 "SQUOOSH", "SQUOOSH", BS_4K, SC_78BIOS, 1, 0xf158faf3},
{"SSSnake",
 "SSSNAKE", "SSSNAKE", BS_4K, SC_78BIOS, 1, 0x8720972f},
{"Stampede",
 "STAMPEDE", "STAMPEDE", BS_2K, SC_78BIOS, 1, 0xcaed83fd},
{"Star Fox",
 "STARFOX", "STARFOX", BS_4K, SC_78BIOS, 1, 0x9e93a230},
{"Star Gunner",
 "STARGUNR", "STARGUNR", BS_4K, SC_78BIOS, 1, 0xac342dea},
{"Star Raiders",
 "STARRAID", "STARRAID", BS_F8, SC_78BIOS, 1, 0x80c51507},
{"Star Ship",
 "STARSHIP", "STARSHIP", BS_2K, SC_78BIOS, 1, 0xba1a271c},
{"Star Strike",
 "STARSTRK", "STARSTRK", BS_4K, SC_78BIOS, 1, 0xf4ae6039},
{"Star Trek: SOS",
 "STARTREK", "STARTREK", BS_F8, SC_78BIOS, 1, 0x39a5f247},
{"Star Voyager",
 "STARVOY", "STARVOY", BS_4K, SC_78BIOS, 1, 0x1ab5305c},
{"Star Wars: The Arcade Game",
 "SWTAG", "SWTAG", BS_E0, SC_78BIOS, 1, 0xce09fcd4},
{"Star Wars: Death Star Battle",
 "SWDSB", "SWDSB", BS_E0, SC_78BIOS, 1, 0xe77f6742},
{"Star Wars: The Empire Strikes Back",
 "SWESB", "SWESB", BS_4K, SC_78BIOS, 1, 0xd3826874},
{"Star Wars: Jedi Arena",
 "SWJA", "SWJA", BS_4K, SC_78BIOS, 1, 0xa4809298},
{"Star Wars: Ewok (proto)",
 "SWEWOK", "SWEWOK", BS_E0, SC_78BIOS, 1, 0x70db5cca},
{"Star Master",
 "STARMSTR", "STARMSTR", BS_4K, SC_78BIOS, 1, 0x0abb25b1},
{"Stargate",
 "STARGATE", "STARGATE", BS_F8SC, SC_78BIOS, 1, 0x7b667ead},
{"Steeple Chase (Sears)",
 "STEEPLE", "STEEPLE", BS_2K, SC_78BIOS, 1, 0x0d6f4f89},
{"Steeple Chase (Video Gems)",
 "STPLCHSE", "STPLCHSE", BS_4K, SC_78BIOS, 1, 0xe8e9b3c7},
{"Stellar Track (Sears)",
 "STELTRAC", "STELTRAC", BS_4K, SC_78BIOS, 1, 0x57b51249},
{"Stell-a-Sketch",
 "SKETCH00", "SKETCH00", BS_SC, SC_SC, 1, 0x9cdc81b6},
{"Strategy X",
 "STRGYX", "STRGYX", BS_4K, SC_78BIOS, 1, 0xcf0de643},
{"Strawberry Shortcake: Musical Match-ups",
 "STRWBRY", "STRWBRY", BS_4K, SC_78BIOS, 1, 0x8437cb09},
{"Street Racer",
 "STRTRCR", "STRTRCR", BS_2K, SC_78BIOS, 1, 0x131e9db3},
{"Stronghold",
 "STRONGHD", "STRONGHD", BS_4K, SC_78BIOS, 1, 0x547d5e17},
{"Stuntman",
 "STUNTMAN", "STUNTMAN", BS_4K, SC_78BIOS, 1, 0x72353ca4},
{"Sub Scan",
 "SUBSCAN", "SUBSCAN", BS_4K, SC_78BIOS, 1, 0x8300508c},
{"Submarine Commander (Sears)",
 "SUBCOMM", "SUBCOMM", BS_4K, SC_78BIOS, 1, 0x8535cab0},
{"Subterraenea",
 "SUBTRN", "SUBTRN", BS_F8, SC_78BIOS, 1, 0xd6eb9991},
{"Suicide Mission (demo)",
 "SUDEMO00", "SUDEMO00", BS_SC, SC_SC, 1, 0xce9cd420},
{"Suicide Mission",
 "SUICID00", "SUICID00", BS_SC, SC_SC, 1, 0x9b4f27df},
{"Summer Games",
 "SUMRGAMS", "SUMRGAMS", BS_F6, SC_78BIOS, 1, 0xc3de9eb8},
{"Super Baseball",
 "SBASBALL", "SBASBALL", BS_F6, SC_78BIOS, 1, 0x76692470},
{"Super Breakout",
 "SBRKOUT", "SBRKOUT", BS_4K, SC_78BIOS, 1, 0x2b520955},
{"Super Challenge Baseball",
 "SCHBASBL", "SCHBASBL", BS_4K, SC_78BIOS, 1, 0xc822b836},
{"Super Challenge Football",
 "SCHFTBAL", "SCHFTBAL", BS_4K, SC_78BIOS, 1, 0xa2a51945},
{"Super Cobra",
 "SCOBRA", "SCOBRA", BS_E0, SC_78BIOS, 1, 0x8d372730},
{"Super Ferrari",
 "SFERRARI", "SFERARI", BS_4K, SC_78BIOS, 1, 0x78aa0d4d},
{"Super Football",
 "SFOOTBAL", "SFOOTBAL", BS_F6SC, SC_78BIOS, 1, 0xcf2cf861},
{"Super Stunt Cycle (Proto)",
 "STNTCYCL", "STNTCYCL", BS_2K, SC_78BIOS, 1, 0xa20bdfde},
{"Superman",
 "SUPERMAN", "SUPERMAN", BS_4K, SC_78BIOS, 1, 0x7d345c2d},
{"Surfer's Paradise (PAL)",
 "SURFPARD", "SURFPARD", BS_4K, SC_78BIOS, 1, 0xc40677f3},
{"Surf's Up (Proto)",
 "SURFSUP", "SURFSUP", BS_F8, SC_78BIOS, 1, 0x63f4690c},
{"Surround",
 "SURND", "SURND", BS_2K, SC_78BIOS, 1, 0x0197d9b1},
{"Survival Island",
 "SURVIV00", "SURVIV00", BS_SC, SC_SC, 1, 0xffa4b961},
{"Survival Island Load 2",
 "SURVIV06", "", BS_NA, SC_NA, 0, 0xf8b0653d},
{"Survival Island Load 3",
 "SURVIV07", "", BS_NA, SC_NA, 0, 0xab62cfac},
{"Survival Run",
 "SURVRUN", "SURVRUN", BS_4K, SC_78BIOS, 1, 0x4d01aeea},
{"Sweat! - Load 1 (proto)",
 "SWEAT100", "SWEAT100", BS_SC, SC_SC, 1, 0xe707a714},
{"Sweat! - Load 2 (proto)",
 "SWEAT200", "SWEAT200", BS_SC, SC_SC, 1, 0x6d05e1cb},
{"Sword of Saros",
 "SWORDS00", "SWORDS00", BS_SC, SC_SC, 1, 0x6c5ff524},
{"Swordfight",
 "SWDFIGT", "SWDFIGT", BS_4K, SC_78BIOS, 1, 0xd001f4ba},
{"Swordquest Earthworld",
 "EARTHWLD", "EARTHWLD", BS_F8, SC_78BIOS, 1, 0x5a4d02f3},
{"Swordquest Fireworld",
 "FIREWLD", "FIREWLD", BS_F8, SC_78BIOS, 1, 0x01253bca},
{"Swordquest Waterworld",
 "WATERWLD", "WATERWLD", BS_F8, SC_78BIOS, 1, 0xb3b098dc},
{"SynthCart (Paul Slocum)",
 "SNTHCART", "SNTHCART", BS_F8, SC_78BIOS, 1, 0xf1a0a2bd},
{"Tac-Scan",
 "TACSCAN", "TACSCAN", BS_4K, SC_78BIOS, 1, 0x8c2f6264},
{"Tanks But No Tanks",
 "TANKS", "TANKS", BS_4K, SC_78BIOS, 1, 0x2a2b87e8},
{"Tape Worm",
 "TAPEWRM", "TAPEWRM", BS_4K, SC_78BIOS, 1, 0x1448e3d2},
{"Tapper",
 "TAPPER", "TAPPER", BS_F8, SC_78BIOS, 1, 0xf74232d8},
{"Task Force",
 "TSKFORCE", "TSKFORCE", BS_4K, SC_78BIOS, 1, 0xe000d39f},
{"Tax Avoiders",
 "TAXAVDRS", "TAXAVDRS", BS_F8, SC_78BIOS, 1, 0x322022a6},
{"Taz",
 "TAZ", "TAZ", BS_F8, SC_78BIOS, 1, 0x90a150cf},
{"Telepathy (proto)",
 "TELPATHY", "TELPATHY", BS_F8, SC_78BIOS, 1, 0x81187400},
{"Tempest (Proto)",
 "TEMPEST", "TEMPEST", BS_F8, SC_78BIOS, 1, 0x8f058b76},
{"Tennis",
 "TENNIS", "TENNIS", BS_2K, SC_78BIOS, 1, 0xcf1e9395},
{"Test Cart (Paul Slocum)",
 "TESTCART", "TESTCART", BS_4K, SC_78BIOS, 1, 0x99066a16},
{"Tetris26",
 "TETRIS26", "TETRIS26", BS_2K, SC_78BIOS, 1, 0xaedb3c29},
{"Texas Chainsaw Massacre",
 "TEXAS", "TEXAS", BS_4K, SC_78BIOS, 1, 0xfa3fba82},
{"This Planet Sucks",
 "PLANSUCS", "PLANSUCS", BS_4K, SC_78BIOS, 1, 0xe45a0a5c},
{"Threshold",
 "THRESHLD", "THRESHLD", BS_4K, SC_78BIOS, 1, 0x1c995fdb},
{"Thrust",
 "THRUST", "THRUST", BS_F6, SC_78BIOS, 1, 0x86c3d590},
{"Thunderground",
 "THNDRGRD", "THNRGND", BS_4K, SC_78BIOS, 1, 0x34132e52},
{"Thwocker (Proto)",
 "THWOKER", "THWOKER", BS_FE, SC_78BIOS, 1, 0xf3a4363c},
{"Time Pilot",
 "TIMEPILT", "TIMEPILT", BS_F8R, SC_78BIOS, 1, 0xf0b19041},
{"Time Pilot (Reversed ROM)",
 "TIMEPILR", "TIMEPILT", BS_F8, SC_78BIOS, 1, 0xf55ac846},
{"Time Warp (PAL)",
 "TIMEWARP", "TIMEWARP", BS_4K, SC_78BIOS, 1, 0xdc25b7ea},
{"Title Match Pro Wresting",
 "TITMATCH", "TITMATCH", BS_F8, SC_78BIOS, 1, 0xe0a683b7},
{"Title Match Pro Wresting",
 "PROWREST", "TITMATCH", BS_F8, SC_78BIOS, 1, 0x62c0ae21},
{"Tomarc the Barbarrian",
 "TOMARC", "TOMARC", BS_F8, SC_78BIOS, 1, 0xe78e761d},
{"Tomcat F-14 Simulator",
 "TOMCAT", "TOMCAT", BS_F6, SC_78BIOS, 1, 0x9e00e64e},
{"Tooth Protectors",
 "TOOTHPRO", "TOOTHPRO", BS_E0, SC_78BIOS, 1, 0xd9088807},
{"Towering Inferno",
 "TOWERING", "TOWERING", BS_4K, SC_78BIOS, 1, 0x12c652b2},
{"Track & Field",
 "TRKFLD", "TRKFLD", BS_F6, SC_78BIOS, 1, 0x56626245},
{"Treasure Below",
 "TRESRBLW", "TRESRBLW", BS_4K, SC_78BIOS, 1, 0x89a7cc41},
{"Trick Shot",
 "TRKSHOT", "TRKSHOT", BS_4K, SC_78BIOS, 1, 0x9a46f393},
{"TRON Deadly Discs",
 "TRONDD", "TRONDD", BS_4K, SC_78BIOS, 1, 0xc44ed695},
{"Tunnel Runner",
 "TUNLRNR", "TUNLRUNR", BS_FA, SC_78BIOS, 1, 0x99ef6cd2},
{"Tunnel Runner",
 "TUNLRUNR", "TUNLRUNR", BS_FA, SC_78BIOS, 1, 0xe26a836d},
{"Turbo (proto - Joke)",
 "TURBO", "TURBO", BS_F8, SC_78BIOS, 1, 0x808eef2c},
{"Turmoil",
 "TURMOIL", "TURMOIL", BS_4K, SC_78BIOS, 1, 0x27229198},
{"Tutankham",
 "TUTANKM", "TUTANKM", BS_E0, SC_78BIOS, 1, 0x7eed7362},
{"UFO Patrol",
 "UFOPAT", "UFOPAT", BS_4K, SC_78BIOS, 1, 0x208bc890},
{"Universal Chaos",
 "UNVCHAOS", "UNVCHAOS", BS_4K, SC_78BIOS, 1, 0xe03a1d85},
{"Up 'n Down",
 "UPNDOWN", "UPNDOWN", BS_F8, SC_78BIOS, 1, 0xb7f842f4},
{"Vanguard",
 "VANGUARD", "VANGUARD", BS_F8, SC_78BIOS, 1, 0xf15763ff},
{"Vault Assault",
 "VAULTAST", "VAULTAST", BS_4K, SC_78BIOS, 1, 0x10970b40},
{"Venture",
 "VENTURE", "VENTURE", BS_4K, SC_78BIOS, 1, 0x29c93a2c},
{"Venture II",
 "VENTURE2", "VENTURE2", BS_4K, SC_78BIOS, 1, 0x8b737fb8},
{"Video Checkers",
 "VIDCHECK", "VIDCHECK", BS_4K, SC_78BIOS, 1, 0x26e0434c},
{"Video Chess",
 "VIDCHESS", "VIDCHESS", BS_4K, SC_78BIOS, 1, 0x1d376918},
{"Video Jogger",
 "VIDJOGGR", "VIDJOGGR", BS_4K, SC_78BIOS, 1, 0xa6412b7e},
{"Video Life",
 "VIDLIFE", "VIDLIFE", BS_CV, SC_78BIOS, 1, 0x266bd1b6},
{"Video Olympics",
 "VIDOLY", "VIDOLY", BS_2K, SC_78BIOS, 1, 0xeb148808},
{"Video Pinball",
 "VIDPINBL", "VIDPINBL", BS_4K, SC_78BIOS, 1, 0x72a13afc},
{"Video Reflex",
 "VIDRFLX", "VIDRFLX", BS_4K, SC_78BIOS, 1, 0x1dc99752},
{"Video Simon",
 "VIDSIMON", "VIDSIMON", BS_4K, SC_78BIOS, 1, 0x19037a99},
{"Virtual Time Machine",
 "VRTLTIME", "VRTLTIME", BS_4K, SC_78BIOS, 1, 0x4d74b5e6},
{"Wabbit",
 "WABBIT", "WABBIT", BS_4K, SC_78BIOS, 1, 0xe26d235f},
{"Wall Ball",
 "WALLBALL", "WALLBALL", BS_4K, SC_78BIOS, 1, 0x646d7ecb},
{"Wall Defender",
 "WALDFNDR", "WALDFNDR", BS_4K, SC_78BIOS, 1, 0x52715a5d},
{"Warring Worms",
 "WARWORMS", "WARWORMS", BS_4K, SC_78BIOS, 1, 0x1d77de94},
{"Warlords",
 "WARLORDS", "WARLORDS", BS_4K, SC_78BIOS, 1, 0x65ef1ff1},
{"Warplock",
 "WARPLOCK", "WARPLOCK", BS_4K, SC_78BIOS, 1, 0x75a39600},
{"Westward Ho (PAL)",
 "WESTHO", "WESTHO", BS_4K, SC_78BIOS, 1, 0x13581639},
{"Wing War",
 "WINGWAR", "WINGWAR", BS_F8, SC_78BIOS, 1, 0xdb2ff8f8},
{"Winter Games",
 "WNTRGMS", "WNTRGMS", BS_F6, SC_78BIOS, 1, 0x64682ffc},
{"Wizard (Proto)",
 "WIZARD", "WIZARD", BS_2K, SC_78BIOS, 1, 0xcb8adc5a},
{"Wizard of Wor",
 "WIZRDWOR", "WIZRDWOR", BS_4K, SC_78BIOS, 1, 0x7faa11df},
{"Word Zapper",
 "WORDZAPR", "WORDZAPR", BS_4K, SC_78BIOS, 1, 0xf1ade906},
{"Worm War I",
 "WORMWAR1", "WORMWAR1", BS_4K, SC_78BIOS, 1, 0x8b7f5bf5},
{"X3V0LuX (ResQsoft)",
 "X3V0LUX", "X3V0LUX", BS_4K, SC_78BIOS, 1, 0xd1a842fc},
{"X-Doom",
 "XDOOMV", "XDOOMV", BS_4K, SC_78BIOS, 1, 0x43c083e3},
{"Xenophobe",
 "XENOPHBE", "XENOPHBE", BS_F6, SC_78BIOS, 1, 0xe30b69ab},
{"Xevious (Proto)",
 "XEVIOUS", "XEVIOUS", BS_F8, SC_78BIOS, 1, 0x8973f4af},
{"X-Man",
 "XMAN", "XMAN", BS_4K, SC_78BIOS, 1, 0xa4baecd9},
{"Yahtzee",
 "YAHTZEE", "YAHTZEE", BS_4K, SC_78BIOS, 1, 0x6dd6cda9},
{"Yar's Revenge",
 "YAREVNGE", "YAREVNGE", BS_4K, SC_78BIOS, 1, 0x1ed37ebd},
{"Zaxxon",
 "ZAXXON", "ZAXXON", BS_F8, SC_78BIOS, 1, 0x00e7d966},
{"Zoo Fun (PAL)",
 "ZOOFUN", "ZOOFUN", BS_4K, SC_78BIOS, 1, 0xc44d074f},
{"Z-Tack",
 "ZTACK", "ZTACK", BS_4K, SC_78BIOS, 1, 0x83bf9a3c},
};

#endif /* MAKEMENU_H */
