/* makemenu.c*/
/*
   Poorly hacked from Bob Colbert's Makewav 4.3 by Chad Schell
   released to the public domain

   The author assumes no responsibility for any damage caused by the use or
   posession of this program.  USE AT YOUR OWN RISK!!!
*/

#include <stdio.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include <sys/stat.h>
#include "queue.h"
#include "find.h"

#ifndef __linux__
	#include <io.h>
	#include <conio.h>
	#include <direct.h>
#endif
#include "makemenu.h"

#define CRC32_REV 0xA0000001	/* CRC-32 polynomial reversed */

unsigned int numRomEntries;
unsigned long crc;				/* holds accumulated CRC */
unsigned long crctab[256];     /* table to help CRC calculation */



struct parmFlags

{

    int     binFileCount;

    struct   qnode *binFileQ;

};





//This only checks if the file/dir exist.

int FileExist(const char* FileName)

{

   struct stat my_stat;

   return (stat(FileName, &my_stat) == 0);

}



int IsDirectory(const char* FileName)

{

   struct stat my_stat;

   if (stat(FileName, &my_stat) != 0) return 0;

   return ((my_stat.st_mode & S_IFDIR) != 0);

}



int MakeDirectory(const char* FileName)

{

#ifndef __linux__

	return _mkdir(FileName);

#else

	return mkdir(FileName, 0777);

#endif

}



/*

** used for generating the CRC lookup table

*/



unsigned long crcrevhware(unsigned long data, unsigned long genpoly, unsigned long accum)

{

  int i;

  data <<= 1;

  for (i=8;i>0;i--) {

    data >>= 1;

    if ((data ^ accum) & 1)

      accum = (accum >> 1) ^ genpoly;

    else

      accum >>= 1;

    }

  return(accum);

}





/*

** init the CRC lookup table

*/



void init_crc(void)

{

  int i;

  for (i=0;i<256;i++)

    crctab[i] = crcrevhware(i,CRC32_REV,0);

}





/*

** update CRC

*/



void ucrc(unsigned char data)

{

   crc = (crc >> 8) ^ crctab[(crc ^ data) & 0xff];

}



int Lookup()

{

    int i = 0;



    while((unsigned int)i < numRomEntries)

    {

        if (RomList[i].CRC == crc)

            return i;

        i++;

    }

    return -1;

}





main(int argc, unsigned char *argv[])

{

	int i;



	long fsize;



	struct parmFlags parms;

	unsigned char newFileName[256];

	char Wildcard[] = "*";

	char *Listed, input;

	FILE *binFile, *MenuTxtFile;

	unsigned char fileBuffer[512*1024];



	numRomEntries = sizeof(RomList)/sizeof(struct romentry);



	printf("This program will search the current directory for Atari ROMs\n");

	printf("that it recognizes and move them to the subdirectory \"GAMES\" (which\n");

	printf("it will create if it does not already exist.)  The ROMs will be renamed\n");

	printf("into 8.3 format for use with the Cuttle Cart 2.  The original ROMs and any\n");

	printf("duplicate ROMs will be deleted.\n");

	printf("\nPlease backup your ROMs to another directory before proceeding.\n\n");

	printf("Proceed? (Y/N): ");

#ifndef __linux__

	input = _getch();		//Under windows this does not require a return.

#else

	input = getchar();		//This will block until return is pressed.

#endif



	if(toupper(input) != 'Y')

		return 0;



	parms.binFileCount = 0;

	parms.binFileQ = NULL;



	myGlob(Wildcard, &parms.binFileQ, &parms.binFileCount);



	if(FileExist("GAMES"))

	{

		if(IsDirectory("GAMES"))

		{

			printf("Warning:  Games directory already exists.\n");

			//Give user a choice here.

		}

		else

		{

			printf("Error: GAMES is not a directory.");

			return 1;

		}

	}

	else

	{

		if(MakeDirectory("GAMES"))

		{

			printf("Error, unable to created GAMES directory.\n");

			return 1;

		}

	}



	if((MenuTxtFile = fopen("MENU.TXT","w"))==NULL)

	{

		printf("Error, unable to create MENU.TXT file.\n");

		return 1;

	}



	init_crc();

	if((Listed = malloc(numRomEntries * sizeof(char))) == NULL)

	{

		printf("Error:  Unable to allocate check list RAM\n");

		return 1;

	}

	memset(Listed, 0, numRomEntries * sizeof(char));



	while (parms.binFileQ != NULL)

	{

		if ((binFile = fopen(parms.binFileQ->fileName,"rb")) == NULL)

		{

			printf("ERROR: unable to open .bin file %s\n",parms.binFileQ->fileName);

			fclose(MenuTxtFile);

			exit(1);

		}



		fseek(binFile,0,SEEK_END);

		fsize = ftell(binFile);

		fseek(binFile,0,SEEK_SET);

		if(fsize > 512*1024)

		{

			printf("Error:  File %s is too large, skipping.\n",parms.binFileQ->fileName);

			fclose(binFile);

		}

		else

		{



			fread(fileBuffer,fsize,1,binFile);

			fclose(binFile);



			crc = 0;

			for (i=0; i<fsize; i++)

				ucrc(fileBuffer[i]);



			i = Lookup();

			if(i == -1)

			{

				printf("No match for file %s.\n",parms.binFileQ->fileName);

			}

			else

			{

				const struct romentry *const ent = &RomList[i];

#ifndef __linux__

				sprintf(newFileName,"GAMES\\%s.BIN",ent->RomName);

#else

				sprintf(newFileName,"GAMES/%s.BIN",ent->RomName);

#endif

				if(FileExist(newFileName))

				{

					remove(newFileName);	//Erase old file

				}

				/*7800 Crossbow and Alien Brigade do not work as they are most commonly

				distributed.  The extra 16K bank needs to be moved from the start to the end

				of the ROM*/

				if((crc == 1936321014) || (crc == 350122756))

				{

					if ((binFile = fopen(parms.binFileQ->fileName,"rb+")) == NULL)

					{

						printf("ERROR: unable to open .bin file %s\n",parms.binFileQ->fileName);

						fclose(MenuTxtFile);

						exit(1);

					}

					fwrite(fileBuffer+(16*1024),(128*1024),1,binFile);

					fwrite(fileBuffer,(16*1024),1,binFile);

					fclose(binFile);

				}

				rename(parms.binFileQ->fileName,newFileName);

				if(ent->InMenu)

				{

					Listed[i] = 1;

				}

			}

		}



		parms.binFileQ = delq(parms.binFileQ);

	}



	// Go through the RomList, which is sorted alphabetically, and

	// print entries for any ROM that was found during the search.

	for(i=0;(unsigned)i<numRomEntries;i++)

	{

		const struct romentry *const ent = &RomList[i];



		if(Listed[i])

		{

			fprintf(MenuTxtFile,"%-0.32s\t%s\t%s\t%s\t%s\n",

				ent->Name,

				ent->RomName,

				ent->InstName,

				BankswitchModeNames[ent->Bankswitch],

				StartupCodeNames[ent->Startup]);

		}

	}



	fclose(MenuTxtFile);

	return 0;

}



